@@ -27,7 +27,7 @@
 #include <KIcon>
 #include <KTabWidget>
 
-#include "analitza.h"
+#include "analyzer.h"
 #include "expression.h"
 #include "graph2d.h"
 #include "variables.h"
@@ -52,6 +52,7 @@ FunctionEdit::FunctionEdit(QWidget *parent)
 	m_name = new KLineEdit(this);
 	
 	m_func = new ExpressionEdit(this);
+	m_func->setExamples(QStringList() << "x**sin x" << "8*sin(3q)" << "t->vector{t, t**2}");
 	m_func->setAns("x");
 	connect(m_func, SIGNAL(textChanged()), this, SLOT(edit()));
 	connect(m_func, SIGNAL(returnPressed()), this, SLOT(ok()));
@@ -87,7 +88,7 @@ FunctionEdit::FunctionEdit(QWidget *parent)
 	m_graph->setReadOnly(true);
 	m_graph->setSquares(false);
 	
-	viewTabs->addTab(m_graph, i18n("Preview"));
+	viewTabs->addTab(m_graph, KIcon("document-preview"), i18n("Preview"));
 	QWidget *options=new QWidget(viewTabs);
 	options->setLayout(new QVBoxLayout);
 	m_uplimit=new ExpressionEdit(options);
@@ -99,7 +100,7 @@ FunctionEdit::FunctionEdit(QWidget *parent)
 	options->layout()->addWidget(new QLabel(i18n("To:"), options));
 	options->layout()->addWidget(m_uplimit);
 	options->layout()->addItem(new QSpacerItem(0,0, QSizePolicy::Expanding, QSizePolicy::Expanding));
-	viewTabs->addTab(options, i18n("Options"));
+	viewTabs->addTab(options, KIcon("configure"), i18n("Options"));
 	connect(m_uplimit, SIGNAL(textChanged()), this, SLOT(updateUplimit()));
 	connect(m_downlimit, SIGNAL(textChanged()), this, SLOT(updateDownlimit()));
 	
@@ -161,7 +162,7 @@ void FunctionEdit::colorChange(int)
 static double calcExp(const Analitza::Expression& exp, Analitza::Variables* v, bool* corr)
 {
 	Q_ASSERT(exp.isCorrect());
-	Analitza::Analitza d(v);
+	Analitza::Analyzer d(v);
 	d.setExpression(exp);
 	Analitza::Expression r=d.calculate();
 	
@@ -299,4 +300,9 @@ function FunctionEdit::createFunction() const
 	return function(name(), expression(), m_vars, color(), m_calcUplimit, m_calcDownlimit);
 }
 
+Analitza::Expression FunctionEdit::expression() const
+{
+	return m_func->expression();
+}
+
 #include "functionedit.moc"
