@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2008 Anne-Marie Mahfouf <annma@kde.org>
+ * Copyright 2001-2009 Anne-Marie Mahfouf <annma@kde.org>
 
      This program is free software; you can redistribute it and/or modify  
      it under the terms of the GNU General Public License as published by  
@@ -18,15 +18,11 @@
 
 #include "khangmanview.h"
 
-#include <kdebug.h>
-#include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpassivepopup.h>
-#include <kpushbutton.h>
-#include <kstandarddirs.h>
-#include <ktoggleaction.h>
-#include <kvbox.h>
+#include <KMessageBox>
+#include <KPassivePopup>
+#include <KPushButton>
+#include <KToggleAction>
+#include <KVBox>
 
 #include <Phonon/MediaObject>
 
@@ -50,7 +46,7 @@
 
 
 KHangManView::KHangManView(KHangMan*parent) 
-        : QWidget(parent), khangman(parent), winCount(0), lossCount(0), m_showhint(false), m_winner(false), 
+        : QWidget(parent), khangman(parent), winCount(0), lossCount(0), m_winner(false), 
 	  m_loser(false), m_bgfill(0), m_numMissedLetters(0), m_posFirstSpace(-1), m_posSecondSpace(-1), 
           m_randomInt(-1), m_hintExists(true), m_accentedLetters(true), m_doc(0), m_theme(0), m_player(0)
 {
@@ -255,8 +251,9 @@ void KHangManView::paintEvent( QPaintEvent * e )
     paintWord(p, e->rect());
     paintMisses(p, e->rect());
     paintHint(p, e->rect());
-    if(m_loser || m_winner) 
+    if (m_loser || m_winner) {
         paintGameOver(p, e->rect());
+    }
 }
 
 
@@ -336,13 +333,14 @@ void KHangManView::paintMisses(QPainter &p, const QRect& )
 
 void KHangManView::paintHint(QPainter &p, const QRect &rect)
 {
-    if(!m_showhint)
+    if (!Prefs::hint()) {
         return;
-
+    }
+    
     QRect myRect = m_theme->hintRect(size());
-    if(!myRect.intersects(rect))
+    if (!myRect.intersects(rect)) {
         return;
-
+    }
 /* Debug */  //p.fillRect(myRect, QBrush(Qt::cyan) );
 
     QColor letterColor = m_theme->letterColor();
@@ -387,7 +385,7 @@ void KHangManView::paintGameOver(QPainter &p, const QRect &rect)
     QRect rectangle=QRect(width()/10, height()*2/10, width()-width()*2/10, height()-height()*4/10);
     p.drawRoundRect(rectangle);
     QFont tFont("Domestic Manners");
-    tFont.setPixelSize( width()/26 );
+    tFont.setPixelSize( (int)   ((width()*42)    /   (26*title.length()))   );
     p.setPen(Qt::black);
     p.setFont(tFont);
     p.drawText(rectangle, Qt::AlignCenter, title);
@@ -395,8 +393,9 @@ void KHangManView::paintGameOver(QPainter &p, const QRect &rect)
     if(m_bgfill<100) {
         m_bgfill+=5;
         QTimer::singleShot(10, this, SLOT(update()));
-	return;
+        return;
     }
+    
     m_playAgainButton->setFocus();
     m_playAgainButton->setDefault(true);
     m_playAgainButton->move(width()/2 - m_playAgainButton->width()/2 , height()/2 + m_playAgainButton->height()/2);
@@ -426,7 +425,7 @@ void KHangManView::resizeEvent(QResizeEvent *)
 
     m_playAgainButton->setGeometry( width()/2 - m_playAgainButton->width()/2 , 
                                     height()/2 + m_playAgainButton->height()/2,
-				    m_playAgainButton->sizeHint().width(), height()/9 );
+    m_playAgainButton->sizeHint().width(), height()/9 );
 }
 
 // ----------------------------------------------------------------
@@ -440,6 +439,7 @@ void KHangManView::slotTry()
         m_letterInput->setFocus();
         return;
     }
+    
     kDebug() << "guess as entered: " << guess;
 
     // Handle the guess.
@@ -505,7 +505,7 @@ void KHangManView::slotTry()
         popup->setPopupStyle( KPassivePopup::Balloon );
         popup->setAutoDelete( true );
         popup->setTimeout( Prefs::missedTimer()*1000 );
-        popup->setView(i18n("This letter has already been guessed.") );
+        popup->setView("KHangMan", i18n("This letter has already been guessed.") );
 
         int  x = 0;
         int  y = 0;
@@ -563,9 +563,7 @@ void KHangManView::newGame()
     m_playAgainButton->setVisible(false);
 
     //reset Hint action
-    khangman->hintAct->setChecked(false);
-    slotSetHint(khangman->hintAct->isChecked());
-
+    khangman->hintAct->setChecked(Prefs::hint());
     khangman->hintAct->setEnabled(m_hintExists);
 
     setGameCount();
@@ -589,8 +587,8 @@ void KHangManView::readFile()
     myFile.setFileName(Prefs::levelFile());
 
     if (!myFile.exists()) {
-        QString  mString = i18n("File $KDEDIR/share/apps/kvtml/%1/%2 not found!\n"
-                                "Check your installation, please!",
+        QString  mString = i18n("File $KDEDIR/share/apps/kvtml/%1/%2 not found.\n"
+                                "Please check your installation.",
                                  Prefs::selectedLanguage(),
                                  Prefs::levelFile());
         KMessageBox::sorry( this, mString, i18n("Error") );
@@ -620,9 +618,9 @@ void KHangManView::game()
     kDebug() << "language " << Prefs::selectedLanguage();
     kDebug() << "level "    << Prefs::levelFile();
 
-    m_word = m_randomList[m_randomInt%NumberOfWords].first;
+    m_word = m_randomList[m_randomInt%m_randomList.count()].first;
     m_word = m_word.toLower();
-    m_hint = m_randomList[m_randomInt%NumberOfWords].second;
+    m_hint = m_randomList[m_randomInt%m_randomList.count()].second;
 
     if (m_word.isEmpty()) {
         ++m_randomInt;
@@ -710,7 +708,9 @@ void KHangManView::slotSetWordsSequence()
             hint = m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(1)->text();
         }
 
-        m_randomList.append(qMakePair(m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->text(), m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->comment()));
+        if (!m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->text().isEmpty()) {
+            m_randomList.append(qMakePair(m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->text(), hint));
+        }
     }
     //shuffle the list
     randomSequence.randomize(m_randomList);
@@ -722,12 +722,6 @@ void KHangManView::setGameCount()
     emit signalChangeStatusbar(i18n("Losses: %1", lossCount), IDS_LOSSES);
 }
 
-void KHangManView::slotSetHint(bool hintBool)
-{
-    m_showhint=hintBool;
-    update();
-}
-
 #include "khangmanview.moc"
 
 // kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
