@@ -47,10 +47,10 @@
 #include <KToggleAction>
 #include <KToolBar>
 #include <KIcon>
-#include <KNS/Engine>
 #include <KApplication>
 #include <KGlobal>
 
+#include <knewstuff3/downloaddialog.h>
 //Project includes
 #include "ui_fontsdlg.h"
 #include "timer.h"
@@ -166,10 +166,10 @@ void KLettres::setupActions()
     m_languageAction->setText(i18nc("@label:listbox", "&Language"));
     m_languageAction->setItems(m_languageNames);
 
-    m_levelsNames.append(i18nc("@item:inlistbox choose level 1", "Level 1" ));
-    m_levelsNames.append(i18nc("@item:inlistbox choose level 2",  "Level 2" ));
-    m_levelsNames.append(i18nc("@item:inlistbox choose level 3",  "Level 3" ));
-    m_levelsNames.append(i18nc("@item:inlistbox choose level 4",  "Level 4" ));
+    m_levelsNames.append(i18ncp("@item:inlistbox choose level", "Level %1" , "Level %1", 1));
+    m_levelsNames.append(i18ncp("@item:inlistbox choose level", "Level %1" , "Level %1", 2));
+    m_levelsNames.append(i18ncp("@item:inlistbox choose level", "Level %1" , "Level %1", 3));
+    m_levelsNames.append(i18ncp("@item:inlistbox choose level", "Level %1" , "Level %1", 4));
     m_levelAction->setItems(m_levelsNames);
     m_levelAction->setCurrentItem(Prefs::level()-1);
 
@@ -231,7 +231,7 @@ void KLettres::optionsPreferences()
     //fontsdlg is the page name, mFont is the widget name, Font Settings is the page display string
     //fonts is the icon
     Timer *m_timer = new Timer();
-    dialog->addPage(m_timer, i18n("Timer"), "clock");
+    dialog->addPage(m_timer, i18n("Timer"), "chronometer");
     connect(dialog, SIGNAL(settingsChanged( const QString &)), this, SLOT(slotUpdateSettings()));
     dialog->setAttribute( Qt::WA_DeleteOnClose );
     dialog->setHelp(QString(), "klettres");
@@ -266,9 +266,8 @@ void KLettres::loadSettings()
 
 void KLettres::slotDownloadNewStuff()
 {
-    KNS::Entry::List entries = KNS::Engine::download();
-    // we need to delete the entry* items in the returned list
-    qDeleteAll(entries);
+    KNS3::DownloadDialog dialog("klettres.knsrc", this);
+    dialog.exec();
 
     //look for languages dirs installed
     QStringList languages = LangUtils::getLanguages();
