@@ -22,37 +22,26 @@
 #include "kstarsdata.h"
 #include "skymap.h"
 #include "skyobjects/skyobject.h"
+#include "skycomponents/culturelist.h"
 #include "Options.h"
 
 #include "ksfilereader.h"
 #include "skylabeler.h"
 
-ConstellationNamesComponent::ConstellationNamesComponent(SkyComponent *parent )
+ConstellationNamesComponent::ConstellationNamesComponent(SkyComposite *parent, CultureList* cultures )
         : ListComponent(parent )
-{}
-
-ConstellationNamesComponent::~ConstellationNamesComponent()
-{}
-
-bool ConstellationNamesComponent::selected()
-{
-    return Options::showCNames() &&
-           ! ( Options::hideOnSlew() && Options::hideCNames() && SkyMap::IsSlewing() );
-
-}
-
-void ConstellationNamesComponent::init()
 {
     uint i = 0;
     bool culture = false;
     KSFileReader fileReader;
     QString cultureName;
 
-    if ( ! fileReader.open( "cnames.dat" ) ) return;
+    if ( ! fileReader.open( "cnames.dat" ) )
+        return;
 
     emitProgressText( i18n("Loading constellation names" ) );
     
-    localCNames = ( Options::useLocalConstellNames() ? true : false );
+    localCNames = Options::useLocalConstellNames();
 
     while ( fileReader.hasMoreLines() ) {
         QString line, name, abbrev;
@@ -64,7 +53,7 @@ void ConstellationNamesComponent::init()
         mode = line.at( 0 );
         if ( mode == 'C') {
             cultureName = line.mid( 2 ).trimmed();
-            culture     = cultureName == KStarsData::Instance()->skyComposite()->currentCulture();
+            culture     = cultureName == cultures->current();
             i++;
             continue;
         }
@@ -88,10 +77,11 @@ void ConstellationNamesComponent::init()
             dms r; r.setH( rah, ram, ras );
             dms d( dd, dm,  ds );
 
-            if ( sgn == '-' ) { d.setD( -1.0*d.Degrees() ); }
+            if ( sgn == '-' )
+                d.setD( -1.0*d.Degrees() );
 
             SkyObject *o = new SkyObject( SkyObject::CONSTELLATION, r, d, 0.0, name, abbrev );
-            objectList().append( o );
+            m_ObjectList.append( o );
 
             //Add name to the list of object names
             objectNames(SkyObject::CONSTELLATION).append( name );
@@ -99,46 +89,50 @@ void ConstellationNamesComponent::init()
     }
 }
 
+ConstellationNamesComponent::~ConstellationNamesComponent()
+{}
+
+bool ConstellationNamesComponent::selected()
+{
+    return Options::showCNames() &&
+           !( Options::hideOnSlew() && Options::hideCNames() && SkyMap::IsSlewing() );
+}
+
 // Don't precess the location of the names
 void ConstellationNamesComponent::update( KSNumbers* )
 {
     if ( ! selected() )
         return;
-
     KStarsData *data = KStarsData::Instance();
-    for( int i = 0; i < objectList().size(); i++ ) {
-        objectList().at( i )->EquatorialToHorizontal( data->lst(),
-                data->geo()->lat() );
-    }
+    foreach(SkyObject* o, m_ObjectList)
+        o->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
 }
 
 void ConstellationNamesComponent::draw( QPainter& psky )
 {
-    if ( ! selected() ) return;
+    if ( ! selected() )
+        return;
 
     SkyMap *map = SkyMap::Instance();
-    KStarsData *data = KStarsData::Instance();
     SkyLabeler* skyLabeler = SkyLabeler::Instance();
     skyLabeler->useStdFont( psky );
-    psky.setPen( QColor( data->colorScheme()->colorNamed( "CNameColor" ) ) );
+    psky.setPen( QColor( KStarsData::Instance()->colorScheme()->colorNamed( "CNameColor" ) ) );
 
     QString name;
-    for ( int i = 0; i < objectList().size(); i++) {
-        SkyObject* p = objectList().at( i );
-        if ( ! map->checkVisibility( p ) ) continue;
+    foreach(SkyObject *p, m_ObjectList) {
+        if( ! map->checkVisibility( p ) )
+            continue;
 
         QPointF o = map->toScreen( p );
-        if ( ! map->onScreen( o ) ) continue;
+        if( ! map->onScreen( o ) )
+            continue;
 
-        if ( Options::useLatinConstellNames() || Options::useLocalConstellNames() ) {
+        if( Options::useLatinConstellNames() || Options::useLocalConstellNames() )
             name = p->name();
-        }
-        else {
+        else
             name = p->name2();
-        }
 
-        float dx = 5.*( name.length() );
-        o.setX( o.x() - dx );
+        o.setX( o.x() - 5.0 * name.length() );
         skyLabeler->drawGuideLabel( psky, o, name, 0.0 );
     }
 
