@@ -22,42 +22,33 @@
 #include "linelistlabel.h"
 
 /**
-	*@class Ecliptic
-	*Represents the ecliptic on the sky map.
-	
-	*@author James B. Bowlin
-	*@version 0.1
-	*/
+ * @class Ecliptic
+ * Represents the ecliptic on the sky map.
+ *	
+ * @author James B. Bowlin
+ * @version 0.1
+ */
 class Ecliptic : public LineListIndex
 {
 public:
 
     /* @short Constructor
-     * @p parent pointer to the parent SkyComponent object
+     * @p parent pointer to the parent SkyComposite object
      * name is the name of the subclass
      */
-    Ecliptic( SkyComponent *parent );
+    Ecliptic( SkyComposite *parent );
 
-    void draw( QPainter& psky );
+    virtual void draw( QPainter& psky );
+    virtual bool selected();
 
-    void drawLabel( QPainter& psky );
-
-    /** @short Initialize the Ecliptic */
-    virtual void init();
-
-    bool selected();
-
-    void updateLabelCandidates( const QPointF& o, LineList* lineList, int i ) {
+protected:
+    virtual void updateLabelCandidates( const QPointF& o, LineList* lineList, int i ) {
         m_label.updateLabelCandidates( o.x(), o.y(), lineList, i );
     }
 
-    void updateLabelCandidates( const QPoint& o, LineList* lineList, int i ) {
-        m_label.updateLabelCandidates( (qreal) o.x(), (qreal) o.y(), lineList, i );
-    }
-
 private:
+    void drawLabel( QPainter& psky );
     LineListLabel m_label;
-
 };
 
 #endif
