@@ -25,39 +25,45 @@
 #include "ksnumbers.h"
 #include "skyobjects/skyobject.h"
 
-SkyComponent::SkyComponent( SkyComponent *parent, bool (*visibleMethod)() )
-{
-    Parent = parent;
-    visible = visibleMethod;
-}
+SkyComponent::SkyComponent( SkyComposite *parent ) :
+    m_parent( parent )
+{}
 
 SkyComponent::~SkyComponent()
-{
-}
-
-bool SkyComponent::isExportable()
-{
-    return true;
-}
-
-void SkyComponent::drawExportable( QPainter& psky )
-{
-    if (isExportable())
-        draw( psky );
-}
+{}
 
 //Hand the message up to SkyMapComposite
 void SkyComponent::emitProgressText( const QString &message ) {
     parent()->emitProgressText( message );
 }
 
-SkyObject* SkyComponent::findByName( const QString & ) { return 0; }
+SkyObject* SkyComponent::findByName( const QString & ) {
+    return 0;
+}
 
-SkyObject* SkyComponent::objectNearest( SkyPoint *, double & ) { return 0; }
+SkyObject* SkyComponent::objectNearest( SkyPoint *, double & ) {
+    return 0;
+}
 
-//Reimplemented in Solar system components
-bool SkyComponent::addTrail( SkyObject * ) { return false; }
-bool SkyComponent::hasTrail( SkyObject *, bool & ) { return false; }
-bool SkyComponent::removeTrail( SkyObject * ) { return false; }
-void SkyComponent::clearTrailsExcept( SkyObject * ) { return; }
-void SkyComponent::drawTrails( QPainter & ) { return; }
+void SkyComponent::drawTrails( QPainter & )
+{}
+
+void SkyComponent::objectsInArea( QList<SkyObject*>& list, const SkyRegion& region )
+{}
+
+
+QHash<int, QStringList>& SkyComponent::getObjectNames() {
+    return parent()->objectNames();
+}
+
+void SkyComponent::removeFromNames(const SkyObject* obj) {
+    QStringList& names = getObjectNames()[obj->type()];
+    int i;
+    i = names.indexOf( obj->name() );
+    if ( i >= 0 )
+        names.removeAt( i );
+
+    i = names.indexOf( obj->longname() );
+    if ( i >= 0 )
+        names.removeAt( i );
+}
