@@ -20,8 +20,6 @@
 #include <QPixmap>
 #include <QPainter>
 
-#include <QRectF>
-#include <QFontMetricsF>
 #include <kglobal.h>
 
 #include "Options.h"
@@ -37,6 +35,7 @@
 #include "binfilehelper.h"
 #include "starblockfactory.h"
 
+
 #if defined(Q_OS_FREEBSD) || defined(Q_OS_NETBSD)
 #include <sys/endian.h>
 #define bswap_16(x) bswap16(x)
@@ -49,7 +48,7 @@
 
 StarComponent *StarComponent::pinstance = 0;
 
-StarComponent::StarComponent(SkyComponent *parent )
+StarComponent::StarComponent(SkyComposite *parent )
     : ListComponent(parent), m_reindexNum(J2000), m_FaintMagnitude(-5.0), 
       starsLoaded(false), focusStar(NULL)
 {
@@ -64,18 +63,23 @@ StarComponent::StarComponent(SkyComponent *parent )
     m_reindexInterval = StarObject::reindexInterval( 304.0 );
 
     m_zoomMagLimit = 0.0;
-    m_reloadSplash = m_reindexSplash = 0;
-    m_validLineNums = false;
 
     for ( int i = 0; i <= MAX_LINENUMBER_MAG; i++ )
         m_labelList[ i ] = new LabelList;
+
+    // Actually load data
+    emitProgressText( i18n("Loading stars" ) );
+    loadStaticData();
+    // Load any deep star catalogs that are available
+    loadDeepStarCatalogs();
+    StarObject::initImages();
 }
 
 StarComponent::~StarComponent() {
     // Empty
 }
 
-StarComponent *StarComponent::Create( SkyComponent *parent ) {
+StarComponent *StarComponent::Create( SkyComposite *parent ) {
     if( pinstance )
         delete pinstance;
     pinstance = new StarComponent( parent );
@@ -86,22 +90,9 @@ bool StarComponent::selected() {
     return Options::showStars();
 }
 
-void StarComponent::init() {
-    emitProgressText( i18n("Loading stars" ) );
-
-    loadStaticData();
-
-    // Load any deep star catalogs that are available
-    loadDeepStarCatalogs();
-
-    StarObject::initImages();
-}
-
 bool StarComponent::addDeepStarCatalogIfExists( const QString &fileName, float trigMag, bool staticstars ) {
     if( BinFileHelper::testFileExists( fileName ) ) {
-        DeepStarComponent *newdsc;
-        m_DeepStarComponents.append( newdsc = new DeepStarComponent( this, fileName, trigMag, staticstars ) );
-        newdsc->init();
+        m_DeepStarComponents.append( new DeepStarComponent( parent(), fileName, trigMag, staticstars ) );
         return true;
     }
     return false;
@@ -175,9 +166,9 @@ void StarComponent::reindexAll( KSNumbers *num )
     }
 
     // re-populate it from the objectList
-    int size = objectList().size();
+    int size = m_ObjectList.size();
     for ( int i = 0; i < size; i++ ) {
-        StarObject* star = (StarObject*) objectList()[ i ];
+        StarObject* star = (StarObject*) m_ObjectList[ i ];
         Trixel trixel = m_skyMesh->indexStar( star );
         m_starIndex->at( trixel )->append( star );
     }
@@ -233,12 +224,11 @@ float StarComponent::starRenderingSize( float mag ) const {
     return size;
 }
 
-float StarComponent::zoomMagnitudeLimit() const {
+float StarComponent::zoomMagnitudeLimit() {
 
     //adjust maglimit for ZoomLevel
     double lgmin = log10(MINZOOM);
-//    double lgmax = log10(MAXZOOM);
-    double lgz = log10(Options::zoomFactor());
+    double lgz   = log10(Options::zoomFactor());
 
     // Old formula:
     //    float maglim = ( 2.000 + 2.444 * Options::memUsage() / 10.0 ) * ( lgz - lgmin ) + Options::magLimitDrawStarZoomOut();
@@ -264,39 +254,37 @@ float StarComponent::zoomMagnitudeLimit() const {
     // Reducing the slope w.r.t zoom factor to avoid the extremely fast increase in star density with zoom
     // that 4.444 gives us (although that is what the derivation gives us)
 
-    float maglim = 3.7 * ( lgz - lgmin ) + 2.222 * log10( static_cast<float>(Options::starDensity()) ) + 3.5;
-
-    return maglim;
-
+    return 3.5 + 3.7*( lgz - lgmin ) + 2.222*log10( static_cast<float>(Options::starDensity()) );
 }
 
 void StarComponent::draw( QPainter& psky )
 {
-    if ( ! selected() ) return;
+    if( !selected() )
+        return;
 
-    SkyMap *map = SkyMap::Instance();
-    KStarsData* data = KStarsData::Instance();
+    SkyMap *map       = SkyMap::Instance();
+    KStarsData* data  = KStarsData::Instance();
     UpdateID updateID = data->updateID();
 
     bool checkSlewing = ( map->isSlewing() && Options::hideOnSlew() );
-    m_hideLabels =  ( map->isSlewing() && Options::hideLabels() ) ||
-                    ! ( Options::showStarMagnitudes() || Options::showStarNames() );
+    m_hideLabels = checkSlewing || !( Options::showStarMagnitudes() || Options::showStarNames() );
 
     //shortcuts to inform whether to draw different objects
-    bool hideFaintStars( checkSlewing && Options::hideStars() );
+    bool hideFaintStars = checkSlewing && Options::hideStars();
     double hideStarsMag = Options::magLimitHideStar();
     reindex( data->updateNum() );
 
     double lgmin = log10(MINZOOM);
     double lgmax = log10(MAXZOOM);
-    double lgz = log10(Options::zoomFactor());
+    double lgz   = log10(Options::zoomFactor());
 
     double maglim;
     m_zoomMagLimit = maglim = zoomMagnitudeLimit();
 
     double labelMagLim = Options::starLabelDensity() / 5.0;
     labelMagLim += ( 12.0 - labelMagLim ) * ( lgz - lgmin) / (lgmax - lgmin );
-    if ( labelMagLim > 8.0 ) labelMagLim = 8.0;
+    if( labelMagLim > 8.0 )
+        labelMagLim = 8.0;
 
     //Loop for drawing star images
 
@@ -307,16 +295,14 @@ void StarComponent::draw( QPainter& psky )
 
     int nTrixels = 0;
 
-    visibleStarCount = 0;
-
-    while ( region.hasNext() ) {
+    while( region.hasNext() ) {
         ++nTrixels;
         Trixel currentRegion = region.next();
         StarList* starList = m_starIndex->at( currentRegion );
         for (int i=0; i < starList->size(); ++i) {
-        
             StarObject *curStar = starList->at( i );
-            if( !curStar ) continue;
+            if( !curStar )
+                continue;
             
             if ( curStar->updateID != updateID )
                 curStar->JITupdate( data );
@@ -324,21 +310,20 @@ void StarComponent::draw( QPainter& psky )
             float mag = curStar->mag();
             
             // break loop if maglim is reached
-            if ( mag > maglim || ( hideFaintStars && curStar->mag() > hideStarsMag ) ) {
+            if ( mag > maglim || ( hideFaintStars && curStar->mag() > hideStarsMag ) )
                 break;
-            }
                  
-            if ( ! map->checkVisibility( curStar ) ) continue;
+            if ( ! map->checkVisibility( curStar ) )
+                continue;
             QPointF o = map->toScreen( curStar );
             
-            if ( ! map->onScreen( o ) ) continue;
+            if ( ! map->onScreen( o ) )
+                continue;
 
-            curStar->draw( psky, o.x(), o.y(), starRenderingSize( mag ), (starColorMode()==0),
-                           starColorIntensity(), true );
-            visibleStarCount++;
-            
-            if ( m_hideLabels || mag > labelMagLim ) continue;
+            curStar->draw( psky, o, starRenderingSize( mag ) );
             
+            if ( m_hideLabels || mag > labelMagLim )
+                continue;
             addLabel( o, curStar );
         }
     }
@@ -351,9 +336,7 @@ void StarComponent::draw( QPainter& psky )
         if ( map->checkVisibility( focusStar ) ) {
             QPointF o = map->toScreen( focusStar );
             if ( map->onScreen( o ) ) {
-                focusStar->draw( psky, o.x(), o.y(), starRenderingSize( mag ), (starColorMode()==0),
-                                 starColorIntensity(), true );
-                visibleStarCount++;
+                focusStar->draw( psky, o, starRenderingSize( mag ) );
             }
         }
     }
@@ -374,7 +357,8 @@ void StarComponent::addLabel( const QPointF& p, StarObject *star )
 
 void StarComponent::drawLabels( QPainter& psky )
 {
-    if ( m_hideLabels ) return;
+    if( m_hideLabels )
+        return;
 
     psky.setPen( QColor( KStarsData::Instance()->colorScheme()->colorNamed( "SNameColor" ) ) );
 
@@ -506,7 +490,7 @@ bool StarComponent::loadStaticData()
                 objectNames(SkyObject::STAR).append( star -> gname(false) );
             }
                 
-            objectList().append( star );
+            m_ObjectList.append( star );
                 
             m_starIndex->at( trixel )->append( star );
             double pm = star->pmMagnitude();
@@ -535,17 +519,28 @@ SkyObject* StarComponent::findStarByGenetiveName( const QString name ) {
 
 // Overrides ListComponent::findByName() to include genetive name and HD index also in the search
 SkyObject* StarComponent::findByName( const QString &name ) {
-    SkyObject *o;
-    foreach ( o, objectList() )
+    foreach(SkyObject* o, m_ObjectList) {
         if ( QString::compare( o->name(), name, Qt::CaseInsensitive ) == 0 || 
              QString::compare( o->longname(), name, Qt::CaseInsensitive ) == 0 || 
              QString::compare( o->name2(), name, Qt::CaseInsensitive ) == 0 || 
              QString::compare( ((StarObject *)o)->gname(false), name, Qt::CaseInsensitive ) == 0)
             return o;
-
+    }
     return 0;
 }
 
+void StarComponent::objectsInArea( QList<SkyObject*>& list, const SkyRegion& region ) 
+{
+    for( SkyRegion::const_iterator it = region.constBegin(); it != region.constEnd(); it++ )
+    {
+        Trixel trixel = it.key();
+        StarList* starlist = m_starIndex->at( trixel );
+        for( int i = 0; starlist && i < starlist->size(); i++ )
+            if( starlist->at(i) && starlist->at(i)->name() != QString("star") )
+                list.push_back( starlist->at(i) );
+    }
+}
+
 SkyObject *StarComponent::findByHDIndex( int HDnum ) {
     KStarsData* data = KStarsData::Instance();
     SkyObject *o;
@@ -617,28 +612,20 @@ SkyObject* StarComponent::objectNearest( SkyPoint *p, double &maxrad )
     double rTry, rBest;
     SkyObject *oTry;
     rBest = maxrad;
-    rTry = maxrad;
+    rTry  = maxrad;
     for( int i = 0; i < m_DeepStarComponents.size(); ++i ) {
-      oTry = m_DeepStarComponents.at( i )->objectNearest( p, rTry );
-      // TODO: Should we multiply rBest by a factor < 1, so that we give higher priority to named stars?
-      if( rTry < rBest ) {
-	rBest = rTry;
-	oBest = oTry;
-      }
+        oTry = m_DeepStarComponents.at( i )->objectNearest( p, rTry );
+        // TODO: Should we multiply rBest by a factor < 1, so that we give higher priority to named stars?
+        if( rTry < rBest ) {
+            rBest = rTry;
+            oBest = oTry;
+        }
     }
     maxrad = rBest;
 
     return oBest;
 }
 
-int StarComponent::starColorMode( void ) const {
-    return KStarsData::Instance()->colorScheme()->starColorMode();
-}
-
-int StarComponent::starColorIntensity( void ) const {
-    return KStarsData::Instance()->colorScheme()->starColorIntensity();
-}
-
 void StarComponent::byteSwap( starData *stardata ) {
     stardata->RA = bswap_32( stardata->RA );
     stardata->Dec = bswap_32( stardata->Dec );
@@ -680,7 +667,6 @@ void StarComponent::printDebugInfo() {
     printf( "Number of visible StarBlocks                 = %8d\n", nBlocks );
     printf( "Number of StarBlocks allocated via SBF       = %8d\n", m_StarBlockFactory.getBlockCount() );
     printf( "Number of unnamed stars in memory            = %8ld\n", nStars );
-    printf( "Number of visible stars (named + unnamed)    = %8ld\n", visibleStarCount );
     printf( "Magnitude of the faintest star in memory     = %8.2f\n", faintMag );
     printf( "Target magnitude limit                       = %8.2f\n", magLim );
     printf( "Size of each StarBlock                       = %8d bytes\n", sizeof( StarBlock ) );
@@ -693,7 +679,6 @@ void StarComponent::printDebugInfo() {
     printf( "Time taken for dynamic load of data          = %8ld ms\n", t_dynamicLoad );
     printf( "Time taken for updating LRU cache            = %8ld ms\n", t_updateCache );
     printf( "Time taken for drawing unnamed stars         = %8ld ms\n", t_drawUnnamed );
-    printf( "Average Number of stars draw per millisecond = %8.2f stars/ms\n", ( (double)visibleStarCount ) / ( t_drawUnnamed + t_drawNamed ) );
     printf( "================================================================\n" );
 }
 
