@@ -33,11 +33,14 @@
 #include "Options.h"
 #include "kstars.h"
 #include "kstarsdata.h"
+#include "ksutils.h"
 #include "simclock.h"
 #include "kspopupmenu.h"
 #include "skyobjects/ksplanetbase.h"
 #include "widgets/infoboxwidget.h"
 
+#include "skycomponents/skymapcomposite.h"
+
 // TODO: Remove if debug key binding is removed
 #include "skycomponents/skylabeler.h"
 #include "skycomponents/starcomponent.h"
@@ -79,10 +82,10 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
     switch ( e->key() ) {
     case Qt::Key_Left :
         if ( Options::useAltAz() ) {
-            focus()->setAz( dms( focus()->az()->Degrees() - step * MINZOOM/Options::zoomFactor() ).reduce() );
+            focus()->setAz( dms( focus()->az().Degrees() - step * MINZOOM/Options::zoomFactor() ).reduce() );
             focus()->HorizontalToEquatorial( data->lst(), data->geo()->lat() );
         } else {
-            focus()->setRA( focus()->ra()->Hours() + 0.05*step * MINZOOM/Options::zoomFactor() );
+            focus()->setRA( focus()->ra().Hours() + 0.05*step * MINZOOM/Options::zoomFactor() );
             focus()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         }
 
@@ -93,10 +96,10 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 
     case Qt::Key_Right :
         if ( Options::useAltAz() ) {
-            focus()->setAz( dms( focus()->az()->Degrees() + step * MINZOOM/Options::zoomFactor() ).reduce() );
+            focus()->setAz( dms( focus()->az().Degrees() + step * MINZOOM/Options::zoomFactor() ).reduce() );
             focus()->HorizontalToEquatorial( data->lst(), data->geo()->lat() );
         } else {
-            focus()->setRA( focus()->ra()->Hours() - 0.05*step * MINZOOM/Options::zoomFactor() );
+            focus()->setRA( focus()->ra().Hours() - 0.05*step * MINZOOM/Options::zoomFactor() );
             focus()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         }
 
@@ -107,12 +110,12 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 
     case Qt::Key_Up :
         if ( Options::useAltAz() ) {
-            focus()->setAlt( focus()->alt()->Degrees() + step * MINZOOM/Options::zoomFactor() );
-            if ( focus()->alt()->Degrees() > 90.0 ) focus()->setAlt( 90.0 );
+            focus()->setAlt( focus()->alt().Degrees() + step * MINZOOM/Options::zoomFactor() );
+            if ( focus()->alt().Degrees() > 90.0 ) focus()->setAlt( 90.0 );
             focus()->HorizontalToEquatorial( data->lst(), data->geo()->lat() );
         } else {
-            focus()->setDec( focus()->dec()->Degrees() + step * MINZOOM/Options::zoomFactor() );
-            if (focus()->dec()->Degrees() > 90.0) focus()->setDec( 90.0 );
+            focus()->setDec( focus()->dec().Degrees() + step * MINZOOM/Options::zoomFactor() );
+            if (focus()->dec().Degrees() > 90.0) focus()->setDec( 90.0 );
             focus()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         }
 
@@ -123,12 +126,12 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 
     case Qt::Key_Down:
         if ( Options::useAltAz() ) {
-            focus()->setAlt( focus()->alt()->Degrees() - step * MINZOOM/Options::zoomFactor() );
-            if ( focus()->alt()->Degrees() < -90.0 ) focus()->setAlt( -90.0 );
+            focus()->setAlt( focus()->alt().Degrees() - step * MINZOOM/Options::zoomFactor() );
+            if ( focus()->alt().Degrees() < -90.0 ) focus()->setAlt( -90.0 );
             focus()->HorizontalToEquatorial(data->lst(), data->geo()->lat() );
         } else {
-            focus()->setDec( focus()->dec()->Degrees() - step * MINZOOM/Options::zoomFactor() );
-            if (focus()->dec()->Degrees() < -90.0) focus()->setDec( -90.0 );
+            focus()->setDec( focus()->dec().Degrees() - step * MINZOOM/Options::zoomFactor() );
+            if (focus()->dec().Degrees() < -90.0) focus()->setDec( -90.0 );
             focus()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         }
 
@@ -211,22 +214,12 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
         if ( !isAngleMode() ) {
             slotBeginAngularDistance();
         }
-
         break;
-
-    case Qt::Key_BracketRight:  // End measuring angular distance
-        if ( isAngleMode() ) {
-            slotEndAngularDistance();
-        }
-
-        break;
-
     case Qt::Key_Escape:        // Cancel angular distance measurement
         if  (isAngleMode() ) {
             slotCancelAngularDistance();
         }
         break;
-
     case Qt::Key_Comma:  //advance one step backward in time
     case Qt::Key_Less:
         if ( data->clock()->isActive() ) data->clock()->stop();
@@ -324,8 +317,9 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
             setClickedObject( focusObject() );
         }
 
-        if ( clickedObject() && clickedObject()->isSolarSystem() ) {
-            if ( ((KSPlanetBase*)clickedObject())->hasTrail() )
+        KSPlanetBase* planet = dynamic_cast<KSPlanetBase*>( clickedObject() );
+        if( planet ) {
+            if( planet->hasTrail() )
                 slotRemovePlanetTrail();
             else
                 slotAddPlanetTrail();
@@ -342,31 +336,13 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
         {
             for ( double alt=-0.5; alt<30.5; alt+=1.0 ) {
                 dms a( alt );
-                dms b( refract( &a, true ) ); //find apparent alt from true alt
-                dms c( refract( &b, false ) );
+                dms b( refract( a, true ) ); //find apparent alt from true alt
+                dms c( refract( b, false ) );
 
                 kDebug() << a.toDMSString() << b.toDMSString() << c.toDMSString();
             }
             break;
         }
-
-        //TIMING
-        // *** Uncomment and insert timing test code here ***
-    case Qt::Key_X:
-        {
-            QTime t;
-            t.start();
-            foreach ( SkyObject *star, data->skyComposite()->stars() )
-            toScreen( star );
-            kDebug() << QString("toScreen() for all stars took %1 ms").arg(t.elapsed());
-            t.start();
-            foreach ( SkyObject *star, data->skyComposite()->stars() )
-            toScreenQuaternion( star );
-            kDebug() << QString("toScreenQuaternion() for all stars took %1 ms").arg(t.elapsed());
-            break;
-        }
-        //END_TIMING
-
     case Qt::Key_R:
         {
             // Toggle relativistic corrections
@@ -375,52 +351,18 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
             forceUpdate();
             break;
         }
-
     case Qt::Key_A:
         Options::setUseAntialias( ! Options::useAntialias() );
         kDebug() << "Use Antialiasing: " << Options::useAntialias();
         forceUpdate();
         break;
-
-        //Test code: create a SkyLine
-        /**
-        case Qt::Key_V:
-        kDebug() << "Create a skyline: ";
-        SkyLine sl( SkyPoint( 12.34, 33.50 ), SkyPoint( 14.00, 40.00 ) );
-        kDebug() << "  " << sl.points().size() << " :: "
-        << sl.point(0)->ra()->toHMSString() << " : " 
-        << sl.point(1)->ra()->toHMSString() << endl;
-
-        SkyPoint p( 11.75, 30.25 );
-        sl.setPoint( 1, &p );
-        kDebug() << "  " << sl.points().size() << " :: "
-        << sl.point(0)->ra()->toHMSString() << " : " 
-        << sl.point(1)->ra()->toHMSString() << endl;
-            break;
-        **/
-        /*
-    case Qt::Key_B:    // print useful debug info about memory allocation for stars
-        data->skyComposite()->getStarComponent()->printDebugInfo();
-        break;
-    case Qt::Key_F:    // verify the integrity of StarBlockLists
-        data->skyComposite()->getStarComponent()->verifySBLIntegrity();
-        break;
-    case Qt::Key_G:    // print Cache structure
-        StarComponent::m_StarBlockFactory.printStructure();
-        break;
-        */
     default:
         // We don't want to do anything in this case. Key is unknown
         return;
     }
 
-    double dHA = data->lst()->Hours() - focus()->ra()->Hours();
-    while ( dHA < 0.0 ) dHA += 24.0;
-    HourAngle.setH( dHA );
-
     if ( arrowKeyPressed ) {
         stopTracking();
-
         if ( scrollCount > 10 ) {
             setDestination( focus() );
             scrollCount = 0;
@@ -464,7 +406,7 @@ void SkyMap::keyReleaseEvent( QKeyEvent *e ) {
         scrollCount = 0;
 
         if ( Options::useAltAz() )
-            setDestinationAltAz( focus()->alt()->Degrees(), focus()->az()->Degrees() );
+            setDestinationAltAz( focus()->alt().Degrees(), focus()->az().Degrees() );
         else
             setDestination( focus() );
 
@@ -536,8 +478,9 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 
     if ( mouseButtonDown ) {
         // set the mouseMoveCursor and set slewing=true, if they are not set yet
-        if (!mouseMoveCursor) setMouseMoveCursor();
-        if (!slewing) {
+        if( !mouseMoveCursor )
+            setMouseMoveCursor();
+        if( !slewing ) {
             slewing = true;
             stopTracking(); //toggle tracking off
         }
@@ -546,24 +489,20 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
         if ( Options::useAltAz() ) {
             mousePoint()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
             clickedPoint()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
-            dms dAz = mousePoint()->az()->Degrees() - clickedPoint()->az()->Degrees();
-            dms dAlt = mousePoint()->alt()->Degrees() - clickedPoint()->alt()->Degrees();
-            focus()->setAz( focus()->az()->Degrees() - dAz.Degrees() ); //move focus in opposite direction
-            focus()->setAlt( focus()->alt()->Degrees() - dAlt.Degrees() );
-
-            if ( focus()->alt()->Degrees() >90.0 ) focus()->setAlt( 90.0 );
-            if ( focus()->alt()->Degrees() <-90.0 ) focus()->setAlt( -90.0 );
-            focus()->setAz( focus()->az()->reduce() );
+            dms dAz = mousePoint()->az().Degrees() - clickedPoint()->az().Degrees();
+            dms dAlt = mousePoint()->alt().Degrees() - clickedPoint()->alt().Degrees();
+            focus()->setAz( focus()->az().Degrees() - dAz.Degrees() ); //move focus in opposite direction
+            focus()->setAz( focus()->az().reduce() );
+            focus()->setAlt(
+                KSUtils::clamp( focus()->alt().Degrees() - dAlt.Degrees() , -90.0 , 90.0 ) );
             focus()->HorizontalToEquatorial( data->lst(), data->geo()->lat() );
         } else {
-            dms dRA = mousePoint()->ra()->Degrees() - clickedPoint()->ra()->Degrees();
-            dms dDec = mousePoint()->dec()->Degrees() - clickedPoint()->dec()->Degrees();
-            focus()->setRA( focus()->ra()->Hours() - dRA.Hours() ); //move focus in opposite direction
-            focus()->setDec( focus()->dec()->Degrees() - dDec.Degrees() );
-
-            if ( focus()->dec()->Degrees() >90.0 ) focus()->setDec( 90.0 );
-            if ( focus()->dec()->Degrees() <-90.0 ) focus()->setDec( -90.0 );
-            focus()->setRA( focus()->ra()->reduce() );
+            dms dRA = mousePoint()->ra().Degrees() - clickedPoint()->ra().Degrees();
+            dms dDec = mousePoint()->dec().Degrees() - clickedPoint()->dec().Degrees();
+            focus()->setRA( focus()->ra().Hours() - dRA.Hours() ); //move focus in opposite direction
+            focus()->setRA( focus()->ra().reduce() );
+            focus()->setDec(
+                KSUtils::clamp( focus()->dec().Degrees() - dDec.Degrees() , -90.0 , 90.0 ) );
             focus()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
         }
 
@@ -573,10 +512,6 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
             scrollCount = 0;
         }
 
-        double dHA = data->lst()->Hours() - focus()->ra()->Hours();
-        while ( dHA < 0.0 ) dHA += 24.0;
-        HourAngle.setH( dHA );
-
         //redetermine RA, Dec of mouse pointer, using new focus
         setMousePoint( fromScreen( e->pos(), data->lst(), data->geo()->lat() ) );
         mousePoint()->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
@@ -585,24 +520,7 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
         forceUpdate();  // must be new computed
 
     } else { //mouse button not down
-        // FIXME: move to KStars
-        KStars* kstars = KStars::Instance();
-        if ( kstars ) {
-            if ( Options::showAltAzField() ) {
-                dms a( mousePoint()->alt()->Degrees() );
-                if ( Options::useAltAz() && Options::useRefraction() )
-                    a = refract( mousePoint()->alt(), true ); //true: compute apparent alt from true alt
-    
-                QString s = QString("%1, %2").arg( mousePoint()->az()->toDMSString(true), //true: force +/- symbol
-                                                   a.toDMSString(true) );                 //true: force +/- symbol
-                kstars->statusBar()->changeItem( s, 1 );
-            }
-            if ( Options::showRADecField() ) {
-                QString s = QString("%1, %2").arg(mousePoint()->ra()->toHMSString(),
-                                                  mousePoint()->dec()->toDMSString(true) ); //true: force +/- symbol
-                kstars->statusBar()->changeItem( s, 2 );
-            }
-        }
+        emit mousePointChanged( mousePoint() );
     }
 }
 
@@ -642,7 +560,7 @@ void SkyMap::mouseReleaseEvent( QMouseEvent * ) {
             slewing = false;
 
             if ( Options::useAltAz() )
-                setDestinationAltAz( focus()->alt()->Degrees(), focus()->az()->Degrees() );
+                setDestinationAltAz( focus()->alt().Degrees(), focus()->az().Degrees() );
             else
                 setDestination( focus() );
         }
@@ -664,10 +582,11 @@ void SkyMap::mousePressEvent( QMouseEvent *e ) {
     }
 
     // if button is down and cursor is not moved set the move cursor after 500 ms
-    QTimer t;
-    t.singleShot (500, this, SLOT (setMouseMoveCursor()));
+    QTimer::singleShot(500, this, SLOT (setMouseMoveCursor()));
 
-    if ( unusablePoint( e->pos() ) ) return;  // break if point is unusable
+    // break if point is unusable
+    if ( unusablePoint( e->pos() ) )
+        return;
 
     if ( !midMouseButtonDown && e->button() == Qt::MidButton ) {
         y0 = 0.5*height() - e->y();  //record y pixel coordinate for middle-button zooming
@@ -688,46 +607,44 @@ void SkyMap::mousePressEvent( QMouseEvent *e ) {
 
         //Find object nearest to clickedPoint()
         double maxrad = 1000.0/Options::zoomFactor();
-        setClickedObject( data->skyComposite()->objectNearest( clickedPoint(), maxrad ) );
+        SkyObject* obj = data->skyComposite()->objectNearest( clickedPoint(), maxrad );
+        setClickedObject( obj );
+        if( obj )
+            setClickedPoint(  obj );
 
-        if ( clickedObject() ) {
-            setClickedPoint( clickedObject() );
-
-            if ( e->button() == Qt::RightButton ) {
-                clickedObject()->showPopupMenu( pmenu, QCursor::pos() );
+        switch( e->button() ) {
+        case Qt::LeftButton:
+            if( kstars ) {
+                QString name;
+                if( clickedObject() )
+                    name = clickedObject()->translatedLongName();
+                else
+                    name = i18n( "Empty sky" );
+                kstars->statusBar()->changeItem(name, 0 );
             }
-
-            if ( kstars && e->button() == Qt::LeftButton ) {
-                kstars->statusBar()->changeItem( clickedObject()->translatedLongName(), 0 );
-            }
-        } else {
-            //Empty sky selected.  If left-click, display "nothing" in the status bar.
-            //If right-click, open "empty" popup menu.
-            setClickedObject( NULL );
-
-            switch (e->button()) {
-            case Qt::LeftButton:
-                if ( kstars )
-                    kstars->statusBar()->changeItem( i18n( "Empty sky" ), 0 );
-                break;
-            case Qt::RightButton: {
-                SkyObject o( SkyObject::TYPE_UNKNOWN, clickedPoint()->ra()->Hours(), clickedPoint()->dec()->Degrees() );
-                pmenu->createEmptyMenu( &o );
-                pmenu->popup( QCursor::pos() );
-                break;
+            break;
+        case Qt::RightButton:
+            if( angularDistanceMode ) {
+                // Compute angular distance.
+                slotEndAngularDistance();
+            } else {
+                // Show popup menu
+                if( clickedObject() ) {
+                    clickedObject()->showPopupMenu( pmenu, QCursor::pos() );
+                } else {
+                    SkyObject o( SkyObject::TYPE_UNKNOWN, clickedPoint()->ra().Hours(), clickedPoint()->dec().Degrees() );
+                    pmenu->createEmptyMenu( &o );
+                    pmenu->popup( QCursor::pos() );
                 }
-            default: ;
             }
+            break;
+        default: ;
         }
     }
 }
 
 void SkyMap::mouseDoubleClickEvent( QMouseEvent *e ) {
-    if ( e->button() == Qt::LeftButton ) {
-        // break if point is unusable
-        if ( unusablePoint( e->pos() ) )
-            return;
-
+    if ( e->button() == Qt::LeftButton && !unusablePoint( e->pos() ) ) {
         mouseButtonDown = false;
         if( e->x() != width()/2 || e->y() != height()/2 )
             slotCenter();
@@ -824,7 +741,7 @@ double SkyMap::magFactor( const int modifier ) {
 }
 
 void SkyMap::incMagLimit( const int modifier ) {
-    double limit = 2.222 * log10( Options::starDensity() ) + 0.35;
+    double limit = 2.222 * log10(static_cast<double>( Options::starDensity() )) + 0.35;
     limit += magFactor( modifier );
     if ( limit > 7.94 ) limit = 7.94;
     Options::setStarDensity( pow( 10, ( limit - 0.35 ) / 2.222) );
@@ -833,7 +750,7 @@ void SkyMap::incMagLimit( const int modifier ) {
 }
 
 void SkyMap::decMagLimit( const int modifier ) {
-    double limit = 2.222 * log10( Options::starDensity() ) + 0.35;
+    double limit = 2.222 * log10(static_cast<double>( Options::starDensity() )) + 0.35;
     limit -= magFactor( modifier );
     if ( limit < 3.55 ) limit = 3.55;
     Options::setStarDensity( pow( 10, ( limit - 0.35 ) / 2.222) );
