@@ -37,6 +37,7 @@
 #include "dialogs/timedialog.h"
 #include "skyobjects/kssun.h"
 #include "skyobjects/ksmoon.h"
+#include "skycomponents/skymapcomposite.h"
 
 WUTDialogUI::WUTDialogUI( QWidget *p ) : QFrame( p ) {
     setupUi( this );
@@ -134,7 +135,7 @@ void WUTDialog::init() {
     }
 
     // sun almanac information
-    KSSun *oSun = reinterpret_cast<KSSun*>( data->objectNamed("Sun") );
+    KSSun *oSun = dynamic_cast<KSSun*>( data->objectNamed("Sun") );
     sunRiseTomorrow = oSun->riseSetTime( TomorrowUT, geo, true );
     sunSetToday = oSun->riseSetTime( EveningUT, geo, false );
     sunRiseToday = oSun->riseSetTime( EveningUT, geo, true );
@@ -146,7 +147,7 @@ void WUTDialog::init() {
 
     oSun->updateCoords( num, true, geo->lat(), &LST );
     if ( oSun->checkCircumpolar( geo->lat() ) ) {
-        if ( oSun->alt()->Degrees() > 0.0 ) {
+        if ( oSun->alt().Degrees() > 0.0 ) {
             sRise = i18n( "circumpolar" );
             sSet = i18n( "circumpolar" );
             sDuration = "00:00";
@@ -189,14 +190,14 @@ void WUTDialog::init() {
         WUT->NightDurationLabel->setText( i18n("Night duration: %1 minute", sDuration ) );
 
     // moon almanac information
-    KSMoon *oMoon = reinterpret_cast<KSMoon*>( data->objectNamed("Moon") );
+    KSMoon *oMoon = dynamic_cast<KSMoon*>( data->objectNamed("Moon") );
     moonRise = oMoon->riseSetTime( UT0, geo, true );
     moonSet = oMoon->riseSetTime( UT0, geo, false );
 
     //check to see if Moon is circumpolar
     oMoon->updateCoords( num, true, geo->lat(), &LST );
     if ( oMoon->checkCircumpolar( geo->lat() ) ) {
-        if ( oMoon->alt()->Degrees() > 0.0 ) {
+        if ( oMoon->alt().Degrees() > 0.0 ) {
             sRise = i18n( "circumpolar" );
             sSet = i18n( "circumpolar" );
         } else {
@@ -333,7 +334,7 @@ bool WUTDialog::checkVisibility(SkyObject *o) {
     double minAlt = 6.0; //An object is considered 'visible' if it is above horizon during civil twilight.
 
     // reject objects that never rise
-    if (o->checkCircumpolar(geo->lat()) == true && o->alt()->Degrees() <= 0) return false;
+    if (o->checkCircumpolar(geo->lat()) == true && o->alt().Degrees() <= 0) return false;
 
     //Initial values for T1, T2 assume all night option of EveningMorningBox
     KStarsDateTime T1 = Evening;
@@ -357,7 +358,7 @@ bool WUTDialog::checkVisibility(SkyObject *o) {
         //check altitude of object at this time.
         sp.EquatorialToHorizontal( &LST, geo->lat() );
 
-        if ( sp.alt()->Degrees() > minAlt ) {
+        if ( sp.alt().Degrees() > minAlt ) {
             visible = true;
             break;
         }
@@ -391,7 +392,7 @@ void WUTDialog::slotDisplayObject( const QString &name ) {
         WUT->ObjectBox->setTitle( o->name() );
 
         if ( o->checkCircumpolar( geo->lat() ) ) {
-            if ( o->alt()->Degrees() > 0.0 ) {
+            if ( o->alt().Degrees() > 0.0 ) {
                 sRise = i18n( "circumpolar" );
                 sSet = i18n( "circumpolar" );
             } else {
