@@ -9,11 +9,10 @@
 // Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
+#ifndef MARBLE_ABSTRACTFILEVIEWITEM_H
+#define MARBLE_ABSTRACTFILEVIEWITEM_H
 
-#ifndef ABSTRACTFILEVIEWITEM_H
-#define ABSTRACTFILEVIEWITEM_H
-
-#include <QtCore/QVariant>
+#include <QtCore/QString>
 
 namespace Marble
 {
