@@ -5,8 +5,8 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 //
@@ -14,9 +14,8 @@
 // done so that you can do it asynchronously.
 //
 
-
-#ifndef DEFERREDFLAG_H
-#define DEFERREDFLAG_H
+#ifndef MARBLE_DEFERREDFLAG_H
+#define MARBLE_DEFERREDFLAG_H
 
 
 #include <QtCore/QObject>
@@ -52,4 +51,4 @@ class DeferredFlag : public QObject
 
 }
 
-#endif // DEFERREDFLAG_H
+#endif
