@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008      Torsten Rahn <tackat@kde.org>"
+// Copyright 2008      Torsten Rahn <tackat@kde.org>
 //
 
 //
@@ -13,8 +13,8 @@
 //
 
 
-#ifndef __MARBLE__IMAGELOADTHREAD_H
-#define __MARBLE__IMAGELOADTHREAD_H
+#ifndef MARBLE_IMAGELOADTHREAD_H
+#define MARBLE_IMAGELOADTHREAD_H
 
 #include <QtCore/QThread>
 #include <QtGui/QImage>
@@ -24,7 +24,8 @@ namespace Marble
 
 class TileId;
 
-class ImageLoadThread : public QThread {
+class ImageLoadThread : public QThread
+{
     Q_OBJECT
 
  public:
@@ -38,4 +39,4 @@ class ImageLoadThread : public QThread {
 
 }
 
-#endif // __MARBLE__IMAGELOADTHREAD_H
+#endif // MARBLE_IMAGELOADTHREAD_H
