@@ -5,17 +5,16 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2004-2007 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
 //
 // The about dialog 
 //
 
-
-#ifndef MARBLEABOUTDIALOG_H
-#define MARBLEABOUTDIALOG_H
+#ifndef MARBLE_MARBLEABOUTDIALOG_H
+#define MARBLE_MARBLEABOUTDIALOG_H
 
 
 #include <QtGui/QDialog>
@@ -46,4 +45,4 @@ class MARBLE_EXPORT MarbleAboutDialog : public QDialog
 
 }
 
-#endif // KATLASABOUTDIALOG_H
+#endif
