@@ -8,13 +8,8 @@
 // Copyright 2008-2009    Torsten Rahn <tackat@kde.org>
 //
 
-//
-// Description: AbstractTile contains the base class for a single quadtile 
-//
-
-
-#ifndef MARBLE_LOCALE_P_H
-#define MARBLE_LOCALE_P_H
+#ifndef MARBLE_MARBLELOCALE_P_H
+#define MARBLE_MARBLELOCALE_P_H
 
 
 namespace Marble
@@ -27,10 +22,10 @@ class MarbleLocalePrivate
     MarbleLocalePrivate();
     virtual ~MarbleLocalePrivate();
 
-    Marble::DistanceUnit m_distanceUnit;
-    Marble::MeasureSystem m_measureSystem;
+    DistanceUnit m_distanceUnit;
+    MeasureSystem m_measureSystem;
 };
 
 }
 
-#endif // MARBLE_LOCALE_P_H
+#endif
