@@ -5,13 +5,13 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2006-2008 Torsten Rahn <tackat@kde.org>"
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>"
+// Copyright 2006-2008 Torsten Rahn <tackat@kde.org>
+// Copyright 2007      Inge Wallin  <ingwa@kde.org>
+// Copyright 2009      Jens-Michael Hoffmann <jensmh@gmx.de>
 //
 
-
-#ifndef MARBLEMAP_H
-#define MARBLEMAP_H
+#ifndef MARBLE_MARBLEMAP_H
+#define MARBLE_MARBLEMAP_H
 
 
 /** @file
@@ -28,18 +28,16 @@
 #include <QtGui/QFont>
 #include <QtGui/QPixmap>
 
-//#include <QtDBus/QtDBus>
-
 #include "marble_export.h"
 #include "GeoDataCoordinates.h"       // In geodata/data/
+#include "GeoDataLookAt.h"
+#include "Quaternion.h"
 #include "global.h"             // types needed in all of marble.
 
 // Qt
 class QAbstractItemModel;
 class QModelIndex;
 class QItemSelectionModel;
-class QStyleOptionGraphicsItem;
-class QUrl;
 
 namespace Marble
 {
@@ -50,17 +48,16 @@ namespace Marble
 class MarbleMapPrivate;
 
 // Marble
-class BoundingBox;
+class GeoDataLatLonAltBox;
 class MarbleModel;
 class ViewParams;
-class HttpDownloadManager;
 class MeasureTool;
 class SunLocator;
 class GpxFileModel;
 class FileViewModel;
 class GeoPainter;
-class MarbleRenderPlugin;
-class MarbleAbstractFloatItem;
+class RenderPlugin;
+class AbstractFloatItem;
 
 /**
  * @short A class that can paint a view of the earth.
@@ -96,7 +93,7 @@ class MarbleAbstractFloatItem;
 class MARBLE_EXPORT MarbleMap : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.marble")
+    Q_CLASSINFO("D-Bus Interface", "org.kde.MarbleMap")
 
  public:
 
@@ -109,7 +106,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * MarbleMap.  The widget will create its own MarbleModel when
      * created.
      */
-    explicit MarbleMap();
+    MarbleMap();
 
     /**
      * @brief Construct a new MarbleMap.
@@ -126,69 +123,60 @@ class MARBLE_EXPORT MarbleMap : public QObject
     /**
      * @brief Return the model that this view shows.
      */
-    MarbleModel  *model() const;
+    MarbleModel *model() const;
 
     // Accessors to internal objects;
-    ViewParams   *viewParams();
-    MeasureTool  *measureTool();
-
-    void  setSize(int width, int height);
-    void  setSize(QSize size);
-    QSize size()   const;
-    int   width()  const;
-    int   height() const;
-
-    /**
-     * @brief Set the download manager to load missing tiles
-     * @param manager the manager instance
-     *
-     * The instance will be destructed by MarbleMap when not
-     * used any longer.
-     */
-    void setDownloadManager( HttpDownloadManager *downloadManager );
+    ViewParams *viewParams();
+    MeasureTool *measureTool();
 
+    void setSize( int width, int height );
+    void setSize( const QSize& size );
+    QSize size() const;
+    int width() const;
+    int height() const;
 
     /**
      * @brief  Return the radius of the globe in pixels.
      */
-    int         radius() const;
+    int radius() const;
 
     /**
      * @brief  Set the radius of the globe in pixels.
      * @param  radius  The new globe radius value in pixels.
      */
-    void        setRadius(int radius);
+    void setRadius( int radius );
 
     /**
      * @brief Return the current zoom level.
      */
-    int         zoom() const;
+    int zoom() const;
 
     /**
-     * @brief Return the current distance.
+     * @brief Return the current distance. Convenience function calling distance(radius())
+     * @see distance(qreal) radius
      */
-    qreal      distance() const;
+    qreal distance() const;
 
     /**
      * @brief  Set the distance of the observer to the globe in km.
      * @param  distance  The new distance in km.
      */
-    void        setDistance( qreal distance );
+    void setDistance( qreal distance );
 
     /**
      * @brief Return the current distance string.
      */
-    QString     distanceString() const;
+    QString distanceString() const;
 
     /**
      * @brief return the minimum zoom value for the current map theme.
      */
-    int         minimumZoom() const;
+    int minimumZoom() const;
 
     /**
      * @brief return the minimum zoom value for the current map theme.
      */
-    int         maximumZoom() const;
+    int maximumZoom() const;
 
     /**
      * @brief return if the map needs to be updated.
@@ -210,7 +198,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      *         @c false if the geographical coordinates are not visible on the screen
      */
     bool screenCoordinates( qreal lon, qreal lat,
-                            int& x, int& y );
+                            qreal& x, qreal& y );
 
     /**
      * @brief Get the Y coordinate of the North Pole.
@@ -231,68 +219,56 @@ class MARBLE_EXPORT MarbleMap : public QObject
                          qreal& lon, qreal& lat,
                          GeoDataCoordinates::Unit = GeoDataCoordinates::Degree );
 
-    /**
-     * @brief Get a quaternion representing a point on the earth corresponding to a pixel in the map.
-     * @param x  the x coordinate of the pixel
-     * @param y  the y coordinate of the pixel
-     * @param q  the out parameter where the result is returned
-     * @return @c true  if the pixel (x, y) is within the globe
-     *         @c false if the pixel (x, y) is outside the globe, i.e. in space
-     */
-    bool    globalQuaternion( int x, int y, Quaternion &q);
-    // FIXME: Make the names of globalQuaternion() and
-    //        geoCoordinates() follow a pattern.
-
     /**
      * @brief Return the longitude of the center point.
      */
-    qreal  centerLongitude() const;
+    qreal centerLongitude() const;
 
     /**
      * @brief Return the latitude of the center point.
      */
-    qreal  centerLatitude()  const;
+    qreal centerLatitude() const;
 
     /**
      * @brief returns the model for all the placemarks on the globe.
      */
-    QAbstractItemModel *placeMarkModel() const;
+    QAbstractItemModel *placemarkModel() const;
 
     /**
      * @brief returns the selection model for all the placemarks on the globe.
      */
-    QItemSelectionModel *placeMarkSelectionModel() const;
+    QItemSelectionModel *placemarkSelectionModel() const;
 
     /**
      * @brief  Return how much the map will move if one of the move slots are called.
      * @return The move step.
      */
-    qreal  moveStep();
+    qreal moveStep();
 
     /**
      * @brief  Add a GeoDataPlacemark file to the model.
-     * @param  filename  the filename of the file containing the PlaceMarks.
+     * @param  filename  the filename of the file containing the Placemarks.
      */
-    void addPlaceMarkFile( const QString &filename );
+    void addPlacemarkFile( const QString &filename );
 
     /**
      * @brief  Add GeoDataPlacemark data as string to the model.
-     * @param  data  the string containing the PlaceMarks.
+     * @param  data  the string containing the Placemarks.
      * @param key  the string needed to identify the data
      */
-    void addPlaceMarkData( const QString& data, const QString& key = "data" );
+    void addPlacemarkData( const QString& data, const QString& key = "data" );
     
     /**
      * @brief  remove data or files from the model.
-     * @param key  either the filename or the string used to identify the data in addPlaceMarkFile and addPlaceMarkData
+     * @param key  either the filename or the string used to identify the data in addPlacemarkFile and addPlacemarkData
      */
-    void removePlaceMarkKey( const QString& key );
+    void removePlacemarkKey( const QString& key );
 
     /**
      * @brief  Return the quaternion that specifies the rotation of the globe.
      * @return The quaternion that describes the rotation of the globe.
      */
-    Quaternion  planetAxis() const;
+    Quaternion planetAxis() const;
 
     /**
      * @brief  Return a QPixmap with the current contents of the map.
@@ -303,133 +279,133 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @brief  Return the property value by name.
      * @return The property value (usually: visibility).
      */
-    bool  propertyValue( const QString& name) const;
+    bool propertyValue( const QString& name ) const;
 
     /**
      * @brief  Return whether the overview map is visible.
      * @return The overview map visibility.
      */
-    bool  showOverviewMap() const;
+    bool showOverviewMap() const;
 
     /**
      * @brief  Return whether the scale bar is visible.
      * @return The scale bar visibility.
      */
-    bool  showScaleBar() const;
+    bool showScaleBar() const;
 
     /**
      * @brief  Return whether the compass bar is visible.
      * @return The compass visibility.
      */
-    bool  showCompass() const;
+    bool showCompass() const;
 
     /**
      * @brief  Return whether the cloud cover is visible.
      * @return The cloud cover visibility.
      */
-    bool  showClouds() const;
+    bool showClouds() const;
 
     /**
      * @brief  Return whether the atmospheric glow is visible.
      * @return The cloud cover visibility.
      */
-    bool  showAtmosphere() const;
+    bool showAtmosphere() const;
 
     /**
      * @brief  Return whether the crosshairs are visible.
      * @return The crosshairs' visibility.
      */
-    bool  showCrosshairs() const;
+    bool showCrosshairs() const;
 
     /**
      * @brief  Return whether the coordinate grid is visible.
      * @return The coordinate grid visibility.
      */
-    bool  showGrid() const;
+    bool showGrid() const;
 
     /**
      * @brief  Return whether the place marks are visible.
      * @return The place mark visibility.
      */
-    bool  showPlaces() const;
+    bool showPlaces() const;
 
     /**
      * @brief  Return whether the city place marks are visible.
      * @return The city place mark visibility.
      */
-    bool  showCities() const;
+    bool showCities() const;
 
     /**
      * @brief  Return whether the terrain place marks are visible.
      * @return The terrain place mark visibility.
      */
-    bool  showTerrain() const;
+    bool showTerrain() const;
 
     /**
      * @brief  Return whether other places are visible.
      * @return The visibility of other places.
      */
-    bool  showOtherPlaces() const;
+    bool showOtherPlaces() const;
 
     /**
      * @brief  Return whether the relief is visible.
      * @return The relief visibility.
      */
-    bool  showRelief() const;
+    bool showRelief() const;
 
     /**
      * @brief  Return whether the elevation model is visible.
      * @return The elevation model visibility.
      */
-    bool  showElevationModel() const;
+    bool showElevationModel() const;
 
     /**
      * @brief  Return whether the ice layer is visible.
      * @return The ice layer visibility.
      */
-    bool  showIceLayer() const;
+    bool showIceLayer() const;
 
     /**
      * @brief  Return whether the borders are visible.
      * @return The border visibility.
      */
-    bool  showBorders() const;
+    bool showBorders() const;
 
     /**
      * @brief  Return whether the rivers are visible.
      * @return The rivers' visibility.
      */
-    bool  showRivers() const;
+    bool showRivers() const;
 
     /**
      * @brief  Return whether the lakes are visible.
      * @return The lakes' visibility.
      */
-    bool  showLakes() const;
+    bool showLakes() const;
 
     /**
      * @brief Return whether Gps Data is visible.
      * @return The Gps Data's visibility.
      */
-    bool  showGps() const;
+    bool showGps() const;
 
     /**
      * @brief  Return whether the frame rate gets displayed.
      * @return the frame rates visibility
      */
-    bool  showFrameRate() const;
+    bool showFrameRate() const;
 
     /**
      * @brief  Returns the limit in kilobytes of the persistent (on hard disc) tile cache.
      * @return the limit of persistent tile cache in kilobytes.
      */
-    quint64  persistentTileCacheLimit() const;
+    quint64 persistentTileCacheLimit() const;
 
     /**
      * @brief  Returns the limit in kilobytes of the volatile (in RAM) tile cache.
      * @return the limit of volatile tile cache in kilobytes.
      */
-    quint64  volatileTileCacheLimit() const;
+    quint64 volatileTileCacheLimit() const;
 
     /**
      * @brief  Return the sun locator object.
@@ -437,8 +413,39 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     SunLocator* sunLocator();
 
-    QList<MarbleRenderPlugin *> renderPlugins() const;
-    QList<MarbleAbstractFloatItem *> floatItems() const;
+    QList<RenderPlugin *> renderPlugins() const;
+    QList<AbstractFloatItem *> floatItems() const;
+
+    /**
+      * @brief Move camera to the given position. This can change
+      * both the zoom value and the position
+      */
+    void flyTo( const GeoDataLookAt &lookAt );
+
+    /**
+      * @brief Return the current camera position
+      */
+    GeoDataLookAt lookAt() const;
+
+    /**
+      * @brief Return the distance (km) at the given globe radius (pixel)
+      */
+    qreal radiusFromDistance( qreal distance ) const;
+
+    /**
+      * @brief Return the distance (km) at the given globe radius (pixel)
+      */
+    qreal distanceFromRadius( qreal radius ) const;
+
+    /**
+      * Returns the zoom value (no unit) corresponding to the given camera distance (km)
+      */
+    qreal zoomFromDistance( qreal distance ) const;
+
+    /**
+      * Returns the distance (km) corresponding to the given zoom value
+      */
+    qreal distanceFromZoom( qreal zoom ) const;
 
  public Q_SLOTS:
 
@@ -450,7 +457,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param painter  The painter to use.
      * @param dirtyRect the rectangle that actually needs repainting.
      */
-    void  paint( GeoPainter &painter, QRect &dirtyRect);
+    void paint( GeoPainter &painter, QRect &dirtyRect );
 
     /**
      * @brief  Zoom the view to a certain zoomlevel
@@ -460,22 +467,22 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * interpretation.  A zoom value around 1000 lets the viewer see
      * all of the earth in the default window.
      */
-    void  zoomView(int zoom);
+    void zoomView( int zoom );
 
     /**
      * @brief  Zoom the view by a certain step
      * @param  zoomStep  the difference between the old zoom and the new
      */
-    void  zoomViewBy(int zoomStep);
+    void zoomViewBy( int zoomStep );
 
     /**
      * @brief  Zoom in by the amount zoomStep.
      */
-    void  zoomIn();
+    void zoomIn();
     /**
      * @brief  Zoom out by the amount zoomStep.
      */
-    void  zoomOut();
+    void zoomOut();
 
     /**
      * @brief  Rotate the view by the two angles phi and theta.
@@ -488,13 +495,13 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * of (lon, lat), otherwise the resulting angle will be the sum of
      * the previous position and the two offsets.
      */
-    void  rotateBy( const qreal &deltaLon, const qreal &deltaLat );
+    void rotateBy( const qreal &deltaLon, const qreal &deltaLat );
 
     /**
      * @brief  Rotate the view by the angle specified by a Quaternion.
      * @param  incRot a quaternion specifying the rotation
      */
-    void  rotateBy( const Quaternion& incRot );
+    void rotateBy( const Quaternion& incRot );
 
     /**
      * @brief  Center the view on a geographical point
@@ -503,13 +510,13 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param  lon  an angle parallel to the longitude lines
      *              +180(W) - -180(E)
      */
-    void  centerOn( const qreal &lon, const qreal &lat );
+    void centerOn( const qreal lon, const qreal lat );
 
     /**
      * @brief  Center the view on a point
      * @param  index  an index for a QModel, indicating a city
      */
-    void  centerOn( const QModelIndex& index );
+    void centerOn( const QModelIndex& index );
 
     /**
      * @brief  Set the latitude for the center point
@@ -529,13 +536,13 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @return @c Equirectangular   a flat map
      * @return @c Mercator          another flat map
      */
-    Projection  projection() const;
+    Projection projection() const;
 
     /**
      * @brief  Set the Projection used for the map
      * @param  projection projection type (e.g. Spherical, Equirectangular, Mercator)
      */
-    void  setProjection( Projection projection );
+    void setProjection( Projection projection );
 
     /**
      * @brief  get the home point
@@ -543,42 +550,42 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @param  lat  the latitude of the home point.
      * @param  zoom the default zoom level of the home point.
      */
-    void  home(qreal &lon, qreal &lat, int& zoom);
+    void home( qreal &lon, qreal &lat, int& zoom );
     /**
      * @brief  Set the home point
      * @param  lon  the longitude of the new home point.
      * @param  lat  the latitude of the new home point.
      * @param  zoom the default zoom level for the new home point.
      */
-    void  setHome(qreal lon, qreal lat, int zoom = 1050);
+    void setHome( qreal lon, qreal lat, int zoom = 1050 );
     /**
      * @brief  Set the home point
      * @param  homePoint  the new home point.
      * @param  zoom       the default zoom level for the new home point.
      */
-    void  setHome(const GeoDataCoordinates& homePoint, int zoom = 1050);
+    void setHome( const GeoDataCoordinates& homePoint, int zoom = 1050 );
 
     /**
      * @brief  Move left by the moveStep.
      */
-    void  moveLeft();
+    void moveLeft();
     /**
      * @brief  Move right by the moveStep.
      */
-    void  moveRight();
+    void moveRight();
     /**
      * @brief  Move up by the moveStep.
      */
-    void  moveUp();
+    void moveUp();
     /**
      * @brief  Move down by the moveStep.
      */
-    void  moveDown();
+    void moveDown();
 
     /**
      * @brief Center the view on the default start point with the default zoom.
      */
-    void  goHome();
+    void goHome();
 
     /**
      * @brief Get the ID of the current map theme
@@ -599,7 +606,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * Example: 
      *    maptheme = "earth/bluemarble/bluemarble.dgml" 
      */
-    void  setMapThemeId( const QString& maptheme );
+    void setMapThemeId( const QString& maptheme );
 
     /**
      * @brief  Sets the value of a map theme property
@@ -634,6 +641,14 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     void setShowClouds( bool visible );
 
+    /**
+     * @brief Set whether the is tile is visible
+     * NOTE: This is part of the transitional debug API
+     *       and might be subject to changes until Marble 0.8
+     * @param visible visibility of the tile
+     */ 
+    void setShowTileId( bool visible );
+
     /**
      * @brief  Set whether the atmospheric glow is visible
      * @param  visible  visibility of the atmospheric glow
@@ -744,12 +759,12 @@ class MARBLE_EXPORT MarbleMap : public QObject
     /**
      * @brief Opens a gpx file for viewing on the Marble Map
      */
-    void openGpxFile( QString &filename );
+    void openGpxFile( const QString &filename );
 
     /**
      * @brief Return a QAbstractItemModel containing GPX files.
      */
-    GpxFileModel  *gpxFileModel();
+    GpxFileModel *gpxFileModel();
 
     /**
      * @brief Return a QAbstractItemModel containing files.
@@ -759,7 +774,7 @@ class MARBLE_EXPORT MarbleMap : public QObject
     void clearPersistentTileCache();
     /**
      * @brief  Set the limit of the persistent (on hard disc) tile cache.
-     * @param  bytes The limit in kilobytes.
+     * @param  bytes The limit in kilobytes, 0 means no limit.
      */
     void setPersistentTileCacheLimit( quint64 kiloBytes );
 
@@ -775,55 +790,56 @@ class MARBLE_EXPORT MarbleMap : public QObject
      */
     void updateChangedMap();
 
-    /**
-     * @brief update part of the map as defined in the BoundingBox
-     */
-    void updateRegion( BoundingBox& );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url string
-     */
-    void setDownloadUrl( const QString &url );
-
-    /**
-     * @brief Set the download url to load missing tiles
-     * @param url the url objects
-     */
-    void setDownloadUrl( const QUrl &url );
-
     bool mapCoversViewport();
 
-    Marble::AngleUnit defaultAngleUnit() const;
-    void setDefaultAngleUnit( Marble::AngleUnit angleUnit );
+    AngleUnit defaultAngleUnit() const;
+    void setDefaultAngleUnit( AngleUnit angleUnit );
 
     QFont defaultFont() const;
     void setDefaultFont( const QFont& font );
-
+    
+    /**
+     * @brief Reload the currently displayed map by reloading texture tiles
+     *        from the Internet. In the future this should be extended to all
+     *        kinds of data which is used in the map.
+     */
+    void reload() const;
+    
  Q_SIGNALS:
     /**
      * @brief Signal that the zoom has changed, and to what.
      * @param zoom  The new zoom value.
      * @see  zoomView()
      */
-    void  zoomChanged( int zoom );
-    void  distanceChanged( const QString& distanceString );
+    void zoomChanged( int zoom );
+    void distanceChanged( const QString& distanceString );
 
     /**
      * @brief Signal that the theme has changed
      * @param theme  Name of the new theme.
      */
-    void  themeChanged( QString theme );
+    void themeChanged( const QString& theme );
 
-    void  projectionChanged( Projection );
+    void projectionChanged( Projection );
 
-    void  mouseMoveGeoPosition( QString );
+    void mouseMoveGeoPosition( const QString& );
 
-    void  mouseClickGeoPosition( qreal lon, qreal lat, GeoDataCoordinates::Unit );
+    void mouseClickGeoPosition( qreal lon, qreal lat, GeoDataCoordinates::Unit );
 
-    void  timeout();
+    void framesPerSecond( qreal fps );
 
-    void  framesPerSecond( qreal fps );
+    /**
+     * This signal is emitted when the repaint of the view was requested.
+     * If available with the @p dirtyRegion which is the region the view will change in.
+     * If dirtyRegion.isEmpty() returns true, the whole viewport has to be repainted.
+     */
+    void repaintNeeded( const QRegion& dirtyRegion );
+
+    /**
+     * This signal is emitted when the visible region of the map changes. This typically happens
+     * when the user moves the map around or zooms.
+     */
+    void visibleLatLonAltBoxChanged( const GeoDataLatLonAltBox& visibleLatLonAltBox );
 
  protected:
 
@@ -832,13 +848,13 @@ class MARBLE_EXPORT MarbleMap : public QObject
      * @brief the globe and before all other layers have been rendered.
      * @param painter 
      */
-    virtual void  customPaint( GeoPainter *painter );
+    virtual void customPaint( GeoPainter *painter );
 
  private:
     Q_DISABLE_COPY( MarbleMap )
-    MarbleMapPrivate  * const d;
+    MarbleMapPrivate * const d;
 };
 
 }
 
-#endif // MARBLEMAP_H
+#endif
