@@ -9,9 +9,8 @@
 // Copyright 2008      Inge Wallin      <inge@lysator.liu.se>
 //
 
-
-#ifndef MERCATORSCANLINETEXTUREMAPPER_H
-#define MERCATORSCANLINETEXTUREMAPPER_H
+#ifndef MARBLE_MERCATORSCANLINETEXTUREMAPPER_H
+#define MARBLE_MERCATORSCANLINETEXTUREMAPPER_H
 
 
 #include "AbstractScanlineTextureMapper.h"
@@ -24,8 +23,8 @@ class MercatorScanlineTextureMapper : public AbstractScanlineTextureMapper
     Q_OBJECT
 
  public:
-    explicit MercatorScanlineTextureMapper( TileLoader *tileLoader,
-					    QObject    *parent = 0 );
+    MercatorScanlineTextureMapper( GeoSceneTexture *textureLayer, StackedTileLoader *tileLoader,
+                                   QObject *parent = 0 );
     void mapTexture( ViewParams *viewParams );
 
  private:
