@@ -9,27 +9,24 @@
 // Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
-
-#ifndef PLACEMARKINFODIALOG_H
-#define PLACEMARKINFODIALOG_H
-
+#ifndef MARBLE_PLACEMARKINFODIALOG_H
+#define MARBLE_PLACEMARKINFODIALOG_H
 
 #include <QtCore/QPersistentModelIndex>
-#include <QtCore/QString>
-#include <QtGui/QFont>
-#include <QtGui/QStatusBar>
 
-#include "DeferredFlag.h"
+class QString;
 
 // FIXME: remove "using namespace" from header
+namespace Marble
+{
+}
 using namespace Marble;
 
 #include "ui_PlacemarkInfoDialog.h"
 
 namespace Marble
 {
-
-class Placemark;
+class DeferredFlag;
 
 class PlacemarkInfoDialog : public QDialog, private Ui::PlacemarkInfoDialog
 {
@@ -40,17 +37,11 @@ class PlacemarkInfoDialog : public QDialog, private Ui::PlacemarkInfoDialog
     explicit PlacemarkInfoDialog( const QPersistentModelIndex &index, QWidget *parent = 0 );
 
  Q_SIGNALS:
-    void source( QString );
+    void source( const QString& );
     
  public Q_SLOTS:
     void setFlagLabel();
-    void showMessage( QString text )
-    {
-        QFont  statusFont = QStatusBar().font();
-        statusFont.setPointSize( qRound( 0.9 * statusFont.pointSize() ) );
-        m_pStatusLabel->setFont( statusFont );
-        m_pStatusLabel->setText( text );
-    }
+    void showMessage( const QString& text );
 
  protected:
     void showContent();
@@ -64,4 +55,4 @@ class PlacemarkInfoDialog : public QDialog, private Ui::PlacemarkInfoDialog
 
 }
 
-#endif // PLACEMARKINFODIALOG_H
+#endif
