@@ -9,13 +9,14 @@
 // Copyright 2007      Inge Wallin  <ingwa@kde.org>
 //
 
-#ifndef TINYWEBBROWSER_H
-#define TINYWEBBROWSER_H
+#ifndef MARBLE_TINYWEBBROWSER_H
+#define MARBLE_TINYWEBBROWSER_H
 
 // Qt
-#include <qglobal.h>
+#include <QtCore/QByteArray>
+#include <QtCore/QString>
+#include <QtCore/QUrl>
 #include <QtWebKit/QWebView>
-#include <QtGui/QDesktopServices>
 
 // Marble
 #include "marble_export.h"
@@ -36,9 +37,11 @@ class MARBLE_EXPORT TinyWebBrowser : public QWebView
     Q_OBJECT
 
  public:
-    TinyWebBrowser( QWidget* parent = 0 );
+    explicit TinyWebBrowser( QWidget* parent = 0 );
     ~TinyWebBrowser();
 
+    static QByteArray userAgent(const QString &platform, const QString &plugin);
+
  public Q_SLOTS:
     void setWikipediaPath( const QString& relativeUrl );
     void print();
@@ -58,4 +61,4 @@ class MARBLE_EXPORT TinyWebBrowser : public QWebView
 
 }
 
-#endif // TINYWEBBROWSER_H
+#endif
