@@ -6,17 +6,18 @@
 // the source code.
 //
 // Copyright 2007      Andrew Manson  <g.real.ate@gmail.com>
-// Copyright 2008      Torsten Rahn   <rahn@kde.org>
+// Copyright 2008-2009 Torsten Rahn   <rahn@kde.org>
 //
 
 
 #include "GeoDataLatLonBox.h"
 
-#include <QtCore/QDebug>
-
+#include "MarbleDebug.h"
 #include "GeoDataCoordinates.h"
 #include "GeoDataLineString.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
@@ -32,6 +33,11 @@ class GeoDataLatLonBoxPrivate
     {
     }
 
+    QString nodeType() const
+    {
+        return GeoDataTypes::GeoDataLatLonBoxType;
+    }
+
     qreal m_north;
     qreal m_south;
     qreal m_east;
@@ -72,6 +78,11 @@ GeoDataLatLonBox::~GeoDataLatLonBox()
     delete d;
 }
 
+QString GeoDataLatLonBox::nodeType() const
+{
+    return d->nodeType();
+}
+
 qreal GeoDataLatLonBox::north( GeoDataCoordinates::Unit unit ) const
 {
     if ( unit == GeoDataCoordinates::Degree ) {
@@ -83,11 +94,12 @@ qreal GeoDataLatLonBox::north( GeoDataCoordinates::Unit unit ) const
 void GeoDataLatLonBox::setNorth( const qreal north, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
-        d->m_north = GeoDataPoint::normalizeLat( north );
+        d->m_north = GeoDataCoordinates::normalizeLat( north );
         break;
     case GeoDataCoordinates::Degree:
-        d->m_north = GeoDataPoint::normalizeLat( north * DEG2RAD );
+        d->m_north = GeoDataCoordinates::normalizeLat( north * DEG2RAD );
         break;
     }
 }
@@ -103,11 +115,12 @@ qreal GeoDataLatLonBox::south( GeoDataCoordinates::Unit unit ) const
 void GeoDataLatLonBox::setSouth( const qreal south, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
-        d->m_south = GeoDataPoint::normalizeLat( south );
+        d->m_south = GeoDataCoordinates::normalizeLat( south );
         break;
     case GeoDataCoordinates::Degree:
-        d->m_south = GeoDataPoint::normalizeLat( south * DEG2RAD );
+        d->m_south = GeoDataCoordinates::normalizeLat( south * DEG2RAD );
         break;
     }
 }
@@ -123,11 +136,12 @@ qreal GeoDataLatLonBox::east( GeoDataCoordinates::Unit unit ) const
 void GeoDataLatLonBox::setEast( const qreal east, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
-        d->m_east = GeoDataPoint::normalizeLon( east );
+        d->m_east = GeoDataCoordinates::normalizeLon( east );
         break;
     case GeoDataCoordinates::Degree:
-        d->m_east = GeoDataPoint::normalizeLon( east * DEG2RAD );
+        d->m_east = GeoDataCoordinates::normalizeLon( east * DEG2RAD );
         break;
     }
 }
@@ -143,11 +157,12 @@ qreal GeoDataLatLonBox::west( GeoDataCoordinates::Unit unit ) const
 void GeoDataLatLonBox::setWest( const qreal west, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
-        d->m_west = GeoDataPoint::normalizeLon( west );
+        d->m_west = GeoDataCoordinates::normalizeLon( west );
         break;
     case GeoDataCoordinates::Degree:
-        d->m_west = GeoDataPoint::normalizeLon( west * DEG2RAD );
+        d->m_west = GeoDataCoordinates::normalizeLon( west * DEG2RAD );
         break;
     }
 }
@@ -155,6 +170,7 @@ void GeoDataLatLonBox::setWest( const qreal west, GeoDataCoordinates::Unit unit
 void GeoDataLatLonBox::setRotation( const qreal rotation, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
         d->m_rotation = rotation;
         break;
@@ -175,6 +191,7 @@ qreal GeoDataLatLonBox::rotation( GeoDataCoordinates::Unit unit ) const
 void GeoDataLatLonBox::boundaries( qreal &north, qreal &south, qreal &east, qreal &west, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
         north = d->m_north;
         south = d->m_south;
@@ -193,17 +210,18 @@ void GeoDataLatLonBox::boundaries( qreal &north, qreal &south, qreal &east, qrea
 void GeoDataLatLonBox::setBoundaries( qreal north, qreal south, qreal east, qreal west, GeoDataCoordinates::Unit unit )
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
-        d->m_north = GeoDataPoint::normalizeLat( north );
-        d->m_south = GeoDataPoint::normalizeLat( south );
-        d->m_east =  GeoDataPoint::normalizeLon( east );
-        d->m_west =  GeoDataPoint::normalizeLon( west );
+        d->m_north = GeoDataCoordinates::normalizeLat( north );
+        d->m_south = GeoDataCoordinates::normalizeLat( south );
+        d->m_east =  GeoDataCoordinates::normalizeLon( east );
+        d->m_west =  GeoDataCoordinates::normalizeLon( west );
         break;
     case GeoDataCoordinates::Degree:
-        d->m_north = GeoDataPoint::normalizeLat( north * DEG2RAD );
-        d->m_south = GeoDataPoint::normalizeLat( south * DEG2RAD );
-        d->m_east =  GeoDataPoint::normalizeLon( east * DEG2RAD );
-        d->m_west =  GeoDataPoint::normalizeLon( west * DEG2RAD );
+        d->m_north = GeoDataCoordinates::normalizeLat( north * DEG2RAD );
+        d->m_south = GeoDataCoordinates::normalizeLat( south * DEG2RAD );
+        d->m_east =  GeoDataCoordinates::normalizeLon( east * DEG2RAD );
+        d->m_west =  GeoDataCoordinates::normalizeLon( west * DEG2RAD );
         break;
     }
 }
@@ -214,6 +232,12 @@ qreal GeoDataLatLonBox::width( GeoDataCoordinates::Unit unit ) const
                                      ? 2 * M_PI - d->m_west + d->m_east
                                      : d->m_east - d->m_west ) );
 
+    // This also covers the case where this bounding box covers the whole
+    // longitude range ( -180 <= lon <= + 180 ).
+    if ( width > 2 * M_PI ) {
+        width = 2 * M_PI;
+    }
+
     if ( unit == GeoDataCoordinates::Degree ) {
         return width * RAD2DEG;
     }
@@ -234,14 +258,45 @@ qreal GeoDataLatLonBox::height( GeoDataCoordinates::Unit unit ) const
 
 bool GeoDataLatLonBox::crossesDateLine() const
 {
-    if ( d->m_east < d->m_west ) {
+    if ( d->m_east < d->m_west ||
+         ( d->m_east == M_PI && d->m_west == -M_PI ) ) {
         return true;
     }
 
     return false;
 }
 
-bool GeoDataLatLonBox::contains( const GeoDataCoordinates &point )
+GeoDataCoordinates GeoDataLatLonBox::center() const
+{
+    if( crossesDateLine() )
+        return GeoDataCoordinates( east() + 2 * M_PI - (east() + 2 * M_PI - west()) / 2,
+                                north() - (north() - south()) / 2 );
+    else
+        return GeoDataCoordinates( east() - (east() - west()) / 2,
+                                north() - (north() - south()) / 2 );
+}
+
+bool GeoDataLatLonBox::containsPole( Pole pole ) const
+{
+    switch ( pole ) {
+      case NorthPole:
+        return ( 2 * north() == +M_PI );
+        break;
+      case SouthPole:
+        return ( 2 * south() == -M_PI );
+        break;
+      default:
+      case AnyPole:
+        return (    2 * north() == +M_PI
+                 || 2 * south() == -M_PI );
+        break;
+    }
+
+    mDebug() << Q_FUNC_INFO << "Invalid pole";
+    return false;
+}
+
+bool GeoDataLatLonBox::contains( const GeoDataCoordinates &point ) const
 {
     qreal lon, lat;
 
@@ -250,7 +305,7 @@ bool GeoDataLatLonBox::contains( const GeoDataCoordinates &point )
     // We need to take care of the normal case ...
     if ( ( ( lon < d->m_west || lon > d->m_east ) && ( d->m_west < d->m_east ) ) ||
     // ... and the case where the bounding box crosses the date line:
-       ( ( lon < d->m_west || lon > d->m_east ) && ( d->m_west < d->m_east ) ) )
+         ( ( lon < d->m_west && lon > d->m_east ) && ( d->m_west > d->m_east ) ) )
         return false;
     
     if ( lat < d->m_south || lat > d->m_north )
@@ -259,7 +314,7 @@ bool GeoDataLatLonBox::contains( const GeoDataCoordinates &point )
     return true;
 }
 
-bool GeoDataLatLonBox::contains( const GeoDataPoint &point )
+bool GeoDataLatLonBox::contains( const GeoDataPoint &point ) const
 {
     qreal lon, lat;
 
@@ -268,7 +323,7 @@ bool GeoDataLatLonBox::contains( const GeoDataPoint &point )
     // We need to take care of the normal case ...
     if ( ( ( lon < d->m_west || lon > d->m_east ) && ( d->m_west < d->m_east ) ) ||
     // ... and the case where the bounding box crosses the date line:
-       ( ( lon < d->m_west || lon > d->m_east ) && ( d->m_west < d->m_east ) ) )
+         ( ( lon > d->m_west || lon < d->m_east ) && ( d->m_west > d->m_east ) ) )
         return false;
     
     if ( lat < d->m_south || lat > d->m_north )
@@ -277,7 +332,7 @@ bool GeoDataLatLonBox::contains( const GeoDataPoint &point )
     return true;
 }
 
-bool GeoDataLatLonBox::contains( const GeoDataLatLonBox &other )
+bool GeoDataLatLonBox::contains( const GeoDataLatLonBox &other ) const
 {
     // check the contain criterion for the latitude first as this is trivial:
 
@@ -321,14 +376,21 @@ bool GeoDataLatLonBox::contains( const GeoDataLatLonBox &other )
                   || ( d->m_east >= other.east() && other.west() >= -M_PI ) ) {
                     return true;
                 }
+
+                // if this bounding box covers the whole longitude range  ( -180 <= lon <= + 180 )
+                // then of course the "inner" bounding box is "inside"
+                if ( d->m_west == -M_PI && d->m_east == +M_PI ) {
+                    return true;
+                }
             }
+
         }
     }
 
     return false;
 }
 
-bool GeoDataLatLonBox::intersects( const GeoDataLatLonBox &other )
+bool GeoDataLatLonBox::intersects( const GeoDataLatLonBox &other ) const
 {
     // check the intersection criterion for the latitude first:
 
@@ -372,7 +434,9 @@ bool GeoDataLatLonBox::intersects( const GeoDataLatLonBox &other )
             else {
                 // "This" bounding box crosses the date line, the other one does not.
                 // So the date line splits "this" bounding box in two parts.
-
+                // 
+                // This also covers the case where this bounding box covers the whole
+                // longitude range ( -180 <= lon <= + 180 ).
                 if ( other.west() <= d->m_east || other.east() >= d->m_west ) {
                         return true;
                 }                
@@ -386,6 +450,7 @@ bool GeoDataLatLonBox::intersects( const GeoDataLatLonBox &other )
 QString GeoDataLatLonBox::toString( GeoDataCoordinates::Unit unit ) const
 {
     switch( unit ){
+    default:
     case GeoDataCoordinates::Radian:
         return QString( "North: %1; West: %2 \n South: %3; East: %4 " )
             .arg( d->m_north * RAD2DEG ).arg( d->m_west * RAD2DEG ).arg( d->m_south * RAD2DEG ).arg( d->m_east * RAD2DEG ); 
@@ -402,9 +467,8 @@ QString GeoDataLatLonBox::toString( GeoDataCoordinates::Unit unit ) const
 
 GeoDataLatLonBox& GeoDataLatLonBox::operator=( const GeoDataLatLonBox &other )
 {
-    // FIXME: this check is not needed, remove or keep it?
-    if ( this == &other )
-        return *this;
+    GeoDataObject::operator=( other );
+    
     *d = *other.d;
     return *this;
 }
@@ -426,12 +490,12 @@ void GeoDataLatLonBox::unpack( QDataStream& stream )
 GeoDataLatLonBox GeoDataLatLonBox::fromLineString(  const GeoDataLineString& lineString  )
 {
     // If the line string is empty return a boundingbox that contains everything
-    if ( lineString.isEmpty() ) {
+    if ( lineString.size() == 0 ) {
         return GeoDataLatLonBox();
     }
 
     qreal lon, lat;
-    lineString.first()->geoCoordinates( lon, lat );
+    lineString.first().geoCoordinates( lon, lat );
     GeoDataCoordinates::normalizeLonLat( lon, lat );
 
     qreal north = lat;
@@ -466,13 +530,13 @@ GeoDataLatLonBox GeoDataLatLonBox::fromLineString(  const GeoDataLineString& lin
     int currentSign = ( lon < 0 ) ? -1 : +1;
     int previousSign = currentSign;
 
-    QVector<GeoDataCoordinates*>::ConstIterator it( lineString.begin() );
-    QVector<GeoDataCoordinates*>::ConstIterator itEnd( lineString.constEnd() );
+    QVector<GeoDataCoordinates>::ConstIterator it( lineString.constBegin() );
+    QVector<GeoDataCoordinates>::ConstIterator itEnd( lineString.constEnd() );
 
     for ( ; it != itEnd; ++it )
     {
         // Get coordinates and normalize them to the desired range.
-        (*it)->geoCoordinates( lon, lat );
+        (it)->geoCoordinates( lon, lat );
         GeoDataCoordinates::normalizeLonLat( lon, lat );
 
         // Determining the maximum and minimum latitude
@@ -535,7 +599,7 @@ GeoDataLatLonBox GeoDataLatLonBox::fromLineString(  const GeoDataLineString& lin
         if ( idlMaxCrossState > 0 ) {
             west = otherWest;
         }
-        if ( ( idlMinCrossState < 0 ) && ( idlMaxCrossState > 0 ) 
+        if ( ( idlMinCrossState < 0 && idlMaxCrossState > 0 ) 
             || idlMinCrossState < -1  || idlMaxCrossState > 1 
             || west < east ) {
             east = +M_PI;
