@@ -11,6 +11,8 @@
 
 #include "GeoDataLineStyle.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
@@ -21,8 +23,9 @@ class GeoDataLineStylePrivate
     {
     }
 
-    ~GeoDataLineStylePrivate()
+    QString nodeType() const
     {
+        return GeoDataTypes::GeoDataLineStyleType;
     }
 
     /// The current width of the line
@@ -34,8 +37,13 @@ GeoDataLineStyle::GeoDataLineStyle()
 {
 }
 
+GeoDataLineStyle::GeoDataLineStyle( const GeoDataLineStyle& other )
+    : GeoDataColorStyle( other ), d (new GeoDataLineStylePrivate( *other.d ) )
+{
+}
+
 GeoDataLineStyle::GeoDataLineStyle( const QColor &color )
-    : d (new GeoDataLineStylePrivate )
+    : d ( new GeoDataLineStylePrivate )
 {
     setColor( color );
 }
@@ -45,6 +53,18 @@ GeoDataLineStyle::~GeoDataLineStyle()
     delete d;
 }
 
+GeoDataLineStyle& GeoDataLineStyle::operator=( const GeoDataLineStyle& other )
+{
+    GeoDataColorStyle::operator=( other );
+    *d = *other.d;
+    return *this;
+}
+
+QString GeoDataLineStyle::nodeType() const
+{
+    return d->nodeType();
+}
+
 void GeoDataLineStyle::setWidth( const float &width )
 {
     d->m_width = width;
