@@ -8,11 +8,13 @@
 // Copyright 2009      Torsten Rahn <rahn@kde.org>
 //
 
-#ifndef GEODATALODPRIVATE_H
-#define GEODATALODPRIVATE_H
+#ifndef MARBLE_GEODATALODPRIVATE_H
+#define MARBLE_GEODATALODPRIVATE_H
 
 #include "GeoDataLod.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
@@ -40,4 +42,4 @@ class GeoDataLodPrivate
 
 } // namespace Marble
 
-#endif //GEODATALODPRIVATE_H
+#endif
