@@ -11,6 +11,8 @@
 
 #include "GeoDataPolyStyle.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
@@ -18,11 +20,13 @@ class GeoDataPolyStylePrivate
 {
   public:
     GeoDataPolyStylePrivate()
+     : m_fill( true ), m_outline( true )
     {
     }
 
-    ~GeoDataPolyStylePrivate()
+    QString nodeType() const
     {
+        return GeoDataTypes::GeoDataPolyStyleType;
     }
 
     /// whether to fill the polygon
@@ -32,12 +36,17 @@ class GeoDataPolyStylePrivate
 };
 
 GeoDataPolyStyle::GeoDataPolyStyle()
-    : d (new GeoDataPolyStylePrivate )
+    : d( new GeoDataPolyStylePrivate )
+{
+}
+
+GeoDataPolyStyle::GeoDataPolyStyle( const GeoDataPolyStyle& other )
+    : GeoDataColorStyle( other ), d( new GeoDataPolyStylePrivate( *other.d ) )
 {
 }
 
 GeoDataPolyStyle::GeoDataPolyStyle( const QColor &color )
-    : d (new GeoDataPolyStylePrivate )
+    : d( new GeoDataPolyStylePrivate )
 {
     setColor( color );
 }
@@ -47,6 +56,18 @@ GeoDataPolyStyle::~GeoDataPolyStyle()
     delete d;
 }
 
+GeoDataPolyStyle& GeoDataPolyStyle::operator=( const GeoDataPolyStyle& other )
+{
+    GeoDataColorStyle::operator=( other );
+    *d = *other.d;
+    return *this;
+}
+
+QString GeoDataPolyStyle::nodeType() const
+{
+    return d->nodeType();
+}
+
 void GeoDataPolyStyle::setFill( const bool &fill )
 {
     d->m_fill = fill;
