@@ -8,8 +8,8 @@
 // Copyright 2009      Bastian Holst <bastianholst@gmx.de>
 //
 
-#ifndef KMLSOUTHTAGHANDLER_H
-#define KMLSOUTHTAGHANDLER_H
+#ifndef MARBLE_KML_KMLSOUTHTAGHANDLER_H
+#define MARBLE_KML_KMLSOUTHTAGHANDLER_H
 
 #include "GeoTagHandler.h"
 
@@ -27,4 +27,4 @@ public:
 }
 }
 
-#endif // KMLSOUTHTAGHANDLER_H
+#endif
