@@ -5,7 +5,7 @@
 // find a copy of this license in LICENSE.txt in the top directory of
 // the source code.
 //
-// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>"
+// Copyright 2008-2009    Torsten Rahn <tackat@kde.org>
 //
 
 //
@@ -13,24 +13,29 @@
 //
 
 
-#ifndef __MARBLE__GLOBAL_P_H
-#define __MARBLE__GLOBAL_P_H
+#ifndef MARBLE_GLOBAL_P_H
+#define MARBLE_GLOBAL_P_H
 
 #include "MarbleLocale.h"
 
+#include "global.h"
 
 namespace Marble
 {
 
 
-class MarbleGlobalPrivate {
+class MarbleGlobalPrivate
+{
  public:
     MarbleGlobalPrivate();
+    
     virtual ~MarbleGlobalPrivate();
 
     MarbleLocale m_locale;
+    
+    MarbleGlobal::Profiles m_profiles;
 };
 
 }
 
-#endif // __MARBLE__GLOBAL_P_H
+#endif // MARBLE_GLOBAL_P_H
