@@ -7,8 +7,8 @@
 //
 // Copyright 2007      Andrew Manson    <g.real.ate@gmail.com>
 //
-#ifndef ROUTE_H
-#define ROUTE_H
+#ifndef MARBLE_ROUTE_H
+#define MARBLE_ROUTE_H
 
 #include "AbstractLayerContainer.h"
 #include "AbstractLayerData.h"
@@ -40,9 +40,6 @@ class Route : public AbstractLayerContainer, public GpsElement,
                        const QSize &canvasSize, 
                        ViewParams *viewParams );
 
-    virtual void draw( ClipPainter *painter, 
-		       const QSize &canvasSize, ViewParams *viewParams ,
-		       const BoundingBox &box );
     virtual void draw( ClipPainter*, const QPoint& );
 
     virtual void printToStream( QTextStream & ) const;
@@ -51,4 +48,4 @@ class Route : public AbstractLayerContainer, public GpsElement,
 
 }
 
-#endif //ROUTE_H
+#endif
