@@ -18,7 +18,10 @@ public:
 public slots:
     void btnADDClicked();
     void addGraph(Graph *g);
-    void selectGraph();
+    void selectFirstGraph();
+signals:
+  void  createGraph(const QString& s);
+  
 };
 
 #endif
